@@ -129,9 +129,27 @@ int service_notification(service *svc, int type, char *not_author, char *not_dat
 
 	log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Creating list of contacts to be notified.\n");
 
-	/* create the contact notification list for this service */
+	/* allocate memory for macros */
 	memset(&mac, 0, sizeof(mac));
-	create_notification_list_from_service(&mac, svc, options, &escalated);
+
+	/* create the contact notification list for this service */
+
+	/* 2011-10-21 MF:  
+	   check viability before adding a contact
+	   to the notification list, requires type
+	   this prevents us from running through all
+	   the steps until notify_contact_of_host|service
+	   is reached. furthermore the $NOTIFICATIONRECIPIENTS$
+	   macro gets only populated with actual recipients,
+	   not all contacts assigned to that host|service.
+	   nice side effect - will resolve long lasting bug.
+
+	   note: checks against timeperiod will happen now(),
+	   and not when the notification is actually being sent.
+
+	   original patch by Opsview Team
+	*/
+	create_notification_list_from_service(&mac, svc, options, &escalated, type);
 
 #ifdef USE_EVENT_BROKER
 	/* send data to event broker */
@@ -209,6 +227,8 @@ int service_notification(service *svc, int type, char *not_author, char *not_dat
 			mac.x[MACRO_NOTIFICATIONTYPE] = (char *)strdup("DOWNTIMECANCELLED");
 		else if (type == NOTIFICATION_CUSTOM)
 			mac.x[MACRO_NOTIFICATIONTYPE] = (char *)strdup("CUSTOM");
+		else if (type == NOTIFICATION_STALKING)
+			mac.x[MACRO_NOTIFICATIONTYPE] = (char *)strdup("STALKING");
 		else if (svc->current_state == STATE_OK)
 			mac.x[MACRO_NOTIFICATIONTYPE] = (char *)strdup("RECOVERY");
 		else
@@ -436,6 +456,14 @@ int check_service_notification_viability(service *svc, int type, int options) {
 		return OK;
 	}
 
+	/***********************************************/
+	/*** SPECIAL CASE FOR STALKING NOTIFICATIONS ***/
+	/***********************************************/
+	
+	/* stalking notifications are good to go at this point, if enabled (this is done before reaching notifications) */
+	if (type == NOTIFICATION_STALKING) {
+		return OK;
+	}
 
 	/****************************************/
 	/*** SPECIAL CASE FOR ACKNOWLEGEMENTS ***/
@@ -563,12 +591,8 @@ int check_service_notification_viability(service *svc, int type, int options) {
 		/* determine the time to use of the first problem point */
 		first_problem_time = svc->last_time_ok; /* not accurate, but its the earliest time we could use in the comparison */
 
-		if ((svc->last_time_warning < first_problem_time) && (svc->last_time_warning > svc->last_time_ok))
-			first_problem_time = svc->last_time_warning;
-		if ((svc->last_time_unknown < first_problem_time) && (svc->last_time_unknown > svc->last_time_ok))
-			first_problem_time = svc->last_time_unknown;
-		if ((svc->last_time_critical < first_problem_time) && (svc->last_time_critical > svc->last_time_ok))
-			first_problem_time = svc->last_time_critical;
+		if ((svc->last_hard_state_change > svc->last_time_ok))
+			first_problem_time = svc->last_hard_state_change;
 
 		if (current_time < (time_t)((first_problem_time == (time_t)0L) ? program_start : first_problem_time) + (time_t)(svc->first_notification_delay * interval_length)) {
 			log_debug_info(DEBUGL_NOTIFICATIONS, 1, "Not enough time has elapsed since the service changed to a non-OK state, so we should not notify about this problem yet\n");
@@ -657,6 +681,15 @@ int check_contact_service_notification_viability(contact *cntct, service *svc, i
 	if (type == NOTIFICATION_CUSTOM)
 		return OK;
 
+	/***********************************************/
+	/*** SPECIAL CASE FOR STALKING NOTIFICATIONS ***/
+	/***********************************************/
+	
+	/* stalking notifications are good to go at this point, if enabled (this is done before reaching notifications) */
+	if (type == NOTIFICATION_STALKING) {
+		return OK;
+	}
+
 
 	/****************************************/
 	/*** SPECIAL CASE FOR FLAPPING ALERTS ***/
@@ -743,12 +776,6 @@ int notify_contact_of_service(icinga_macros *mac, contact *cntct, service *svc,
 	int neb_result;
 
 	log_debug_info(DEBUGL_FUNCTIONS, 0, "notify_contact_of_service()\n");
-	log_debug_info(DEBUGL_NOTIFICATIONS, 2, "** Attempting to notifying contact '%s'...\n", cntct->name);
-
-	/* check viability of notifying this user */
-	/* acknowledgements are no longer excluded from this test - added 8/19/02 Tom Bertelson */
-	if (check_contact_service_notification_viability(cntct, svc, type, options) == ERROR)
-		return ERROR;
 
 	log_debug_info(DEBUGL_NOTIFICATIONS, 2, "** Notifying contact '%s'\n", cntct->name);
 
@@ -1103,8 +1130,8 @@ int should_service_notification_be_escalated(service *svc) {
 }
 
 
-/* given a service, create a list of contacts to be notified, removing duplicates */
-int create_notification_list_from_service(icinga_macros *mac, service *svc, int options, int *escalated) {
+/* given a service, create a list of contacts to be notified, removing duplicates, checking contact notification viability */
+int create_notification_list_from_service(icinga_macros *mac, service *svc, int options, int *escalated, int type) {
 	serviceescalation *temp_se = NULL;
 	contactsmember *temp_contactsmember = NULL;
 	contact *temp_contact = NULL;
@@ -1149,7 +1176,12 @@ int create_notification_list_from_service(icinga_macros *mac, service *svc, int
 			for (temp_contactsmember = temp_se->contacts; temp_contactsmember != NULL; temp_contactsmember = temp_contactsmember->next) {
 				if ((temp_contact = temp_contactsmember->contact_ptr) == NULL)
 					continue;
-				add_notification(mac, temp_contact);
+				/* check now if the contact can be notified */
+				if (check_contact_service_notification_viability(temp_contact, svc, type, options) == OK)
+					add_notification(mac, temp_contact);
+				else
+					log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Not adding contact '%s'\n",temp_contact->name);
+					
 			}
 
 			log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Adding members of contact groups from service escalation(s) to notification list.\n");
@@ -1162,7 +1194,11 @@ int create_notification_list_from_service(icinga_macros *mac, service *svc, int
 				for (temp_contactsmember = temp_contactgroup->members; temp_contactsmember != NULL; temp_contactsmember = temp_contactsmember->next) {
 					if ((temp_contact = temp_contactsmember->contact_ptr) == NULL)
 						continue;
-					add_notification(mac, temp_contact);
+					/* check now if the contact can be notified */
+					if (check_contact_service_notification_viability(temp_contact, svc, type, options) == OK)
+						add_notification(mac, temp_contact);
+					else
+						log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Not adding contact '%s'\n",temp_contact->name);
 				}
 			}
 		}
@@ -1177,7 +1213,11 @@ int create_notification_list_from_service(icinga_macros *mac, service *svc, int
 		for (temp_contactsmember = svc->contacts; temp_contactsmember != NULL; temp_contactsmember = temp_contactsmember->next) {
 			if ((temp_contact = temp_contactsmember->contact_ptr) == NULL)
 				continue;
-			add_notification(mac, temp_contact);
+			/* check now if the contact can be notified */
+                        if (check_contact_service_notification_viability(temp_contact, svc, type, options) == OK)
+                                add_notification(mac, temp_contact);
+                        else
+                                log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Not adding contact '%s'\n",temp_contact->name);
 		}
 
 		/* add all contacts that belong to contactgroups for this service */
@@ -1188,7 +1228,11 @@ int create_notification_list_from_service(icinga_macros *mac, service *svc, int
 			for (temp_contactsmember = temp_contactgroup->members; temp_contactsmember != NULL; temp_contactsmember = temp_contactsmember->next) {
 				if ((temp_contact = temp_contactsmember->contact_ptr) == NULL)
 					continue;
-				add_notification(mac, temp_contact);
+                        	/* check now if the contact can be notified */
+	                        if (check_contact_service_notification_viability(temp_contact, svc, type, options) == OK)
+	                                add_notification(mac, temp_contact);
+	                        else
+	                                log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Not adding contact '%s'\n",temp_contact->name);
 			}
 		}
 	}
@@ -1262,7 +1306,23 @@ int host_notification(host *hst, int type, char *not_author, char *not_data, int
 	log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Creating list of contacts to be notified.\n");
 
 	/* create the contact notification list for this host */
-	create_notification_list_from_host(&mac, hst, options, &escalated);
+
+        /* 2011-10-21 MF:  
+           check viability before adding a contact
+           to the notification list, requires type
+           this prevents us from running through all
+           the steps until notify_contact_of_host|service
+           is reached. furthermore the $NOTIFICATIONRECIPIENTS$
+           macro gets only populated with actual recipients,
+           not all contacts assigned to that host|service.
+           nice side effect - will resolve long lasting bug.
+
+           note: checks against timeperiod will happen now(),
+           and not when the notification is actually being sent.
+
+           original patch by Opsview Team
+        */
+	create_notification_list_from_host(&mac, hst, options, &escalated, type);
 
 #ifdef USE_EVENT_BROKER
 	/* send data to event broker */
@@ -1339,6 +1399,8 @@ int host_notification(host *hst, int type, char *not_author, char *not_data, int
 			mac.x[MACRO_NOTIFICATIONTYPE] = (char *)strdup("DOWNTIMECANCELLED");
 		else if (type == NOTIFICATION_CUSTOM)
 			mac.x[MACRO_NOTIFICATIONTYPE] = (char *)strdup("CUSTOM");
+		else if (type == NOTIFICATION_STALKING)
+			mac.x[MACRO_NOTIFICATIONTYPE] = (char *)strdup("STALKING");
 		else if (hst->current_state == HOST_UP)
 			mac.x[MACRO_NOTIFICATIONTYPE] = (char *)strdup("RECOVERY");
 		else
@@ -1653,10 +1715,8 @@ int check_host_notification_viability(host *hst, int type, int options) {
 		/* determine the time to use of the first problem point */
 		first_problem_time = hst->last_time_up; /* not accurate, but its the earliest time we could use in the comparison */
 
-		if ((hst->last_time_down < first_problem_time) && (hst->last_time_down > hst->last_time_up))
-			first_problem_time = hst->last_time_down;
-		if ((hst->last_time_unreachable < first_problem_time) && (hst->last_time_unreachable > hst->last_time_unreachable))
-			first_problem_time = hst->last_time_unreachable;
+		if ((hst->last_hard_state_change > hst->last_time_up))
+			first_problem_time = hst->last_hard_state_change;
 
 		if (current_time < (time_t)((first_problem_time == (time_t)0L) ? program_start : first_problem_time) + (time_t)(hst->first_notification_delay * interval_length)) {
 			log_debug_info(DEBUGL_NOTIFICATIONS, 1, "Not enough time has elapsed since the host changed to a non-UP state (or since program start), so we shouldn't notify about this problem yet.\n");
@@ -1818,12 +1878,6 @@ int notify_contact_of_host(icinga_macros *mac, contact *cntct, host *hst, int ty
 	int neb_result;
 
 	log_debug_info(DEBUGL_FUNCTIONS, 0, "notify_contact_of_host()\n");
-	log_debug_info(DEBUGL_NOTIFICATIONS, 2, "** Attempting to notifying contact '%s'...\n", cntct->name);
-
-	/* check viability of notifying this user about the host */
-	/* acknowledgements are no longer excluded from this test - added 8/19/02 Tom Bertelson */
-	if (check_contact_host_notification_viability(cntct, hst, type, options) == ERROR)
-		return ERROR;
 
 	log_debug_info(DEBUGL_NOTIFICATIONS, 2, "** Notifying contact '%s'\n", cntct->name);
 
@@ -2088,8 +2142,8 @@ int should_host_notification_be_escalated(host *hst) {
 }
 
 
-/* given a host, create a list of contacts to be notified, removing duplicates */
-int create_notification_list_from_host(icinga_macros *mac, host *hst, int options, int *escalated) {
+/* given a host, create a list of contacts to be notified, removing duplicates, checking contact notification viability */
+int create_notification_list_from_host(icinga_macros *mac, host *hst, int options, int *escalated, int type) {
 	hostescalation *temp_he = NULL;
 	contactsmember *temp_contactsmember = NULL;
 	contact *temp_contact = NULL;
@@ -2134,7 +2188,11 @@ int create_notification_list_from_host(icinga_macros *mac, host *hst, int option
 			for (temp_contactsmember = temp_he->contacts; temp_contactsmember != NULL; temp_contactsmember = temp_contactsmember->next) {
 				if ((temp_contact = temp_contactsmember->contact_ptr) == NULL)
 					continue;
-				add_notification(mac, temp_contact);
+				/* check now if the contact can be notified */
+				if (check_contact_host_notification_viability(temp_contact, hst, type, options) == OK)
+					add_notification(mac, temp_contact);
+				else
+					log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Not adding contact '%s'\n", temp_contact->name);
 			}
 
 			log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Adding members of contact groups from host escalation(s) to notification list.\n");
@@ -2147,7 +2205,11 @@ int create_notification_list_from_host(icinga_macros *mac, host *hst, int option
 				for (temp_contactsmember = temp_contactgroup->members; temp_contactsmember != NULL; temp_contactsmember = temp_contactsmember->next) {
 					if ((temp_contact = temp_contactsmember->contact_ptr) == NULL)
 						continue;
-					add_notification(mac, temp_contact);
+	                                /* check now if the contact can be notified */
+	                                if (check_contact_host_notification_viability(temp_contact, hst, type, options) == OK)
+	                                        add_notification(mac, temp_contact);
+	                                else
+	                                        log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Not adding contact '%s'\n", temp_contact->name);
 				}
 			}
 		}
@@ -2164,7 +2226,11 @@ int create_notification_list_from_host(icinga_macros *mac, host *hst, int option
 		for (temp_contactsmember = hst->contacts; temp_contactsmember != NULL; temp_contactsmember = temp_contactsmember->next) {
 			if ((temp_contact = temp_contactsmember->contact_ptr) == NULL)
 				continue;
-			add_notification(mac, temp_contact);
+                        /* check now if the contact can be notified */
+                        if (check_contact_host_notification_viability(temp_contact, hst, type, options) == OK)
+                                add_notification(mac, temp_contact);
+                        else
+                                log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Not adding contact '%s'\n", temp_contact->name);
 		}
 
 		log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Adding members of contact groups for host to notification list.\n");
@@ -2178,7 +2244,11 @@ int create_notification_list_from_host(icinga_macros *mac, host *hst, int option
 			for (temp_contactsmember = temp_contactgroup->members; temp_contactsmember != NULL; temp_contactsmember = temp_contactsmember->next) {
 				if ((temp_contact = temp_contactsmember->contact_ptr) == NULL)
 					continue;
-				add_notification(mac, temp_contact);
+	                        /* check now if the contact can be notified */
+	                        if (check_contact_host_notification_viability(temp_contact, hst, type, options) == OK)
+	                                add_notification(mac, temp_contact);
+	                        else
+	                                log_debug_info(DEBUGL_NOTIFICATIONS, 2, "Not adding contact '%s'\n", temp_contact->name);
 			}
 		}
 	}
