@@ -25,6 +25,7 @@
 #include "../include/common.h"
 #include "../include/locations.h"
 #include "../include/objects.h"
+#include "../include/macros.h"
 #include "../include/statusdata.h"
 
 #include "../include/cgiutils.h"
@@ -65,7 +66,7 @@ char            *ping_syntax = NULL;
 char		*csv_delimiter = CSV_DELIMITER;
 char		*csv_data_enclosure = CSV_DATA_ENCLOSURE;
 
-char		highlight_table_rows = FALSE;
+char		highlight_table_rows = TRUE;
 
 char            nagios_check_command[MAX_INPUT_BUFFER] = "";
 char            nagios_process_info[MAX_INPUT_BUFFER] = "";
@@ -89,6 +90,10 @@ extern time_t   last_command_check;
 extern time_t   last_log_rotation;
 extern time_t	status_file_creation_time;
 
+/* resource file */
+char		resource_file[MAX_INPUT_BUFFER];
+extern char 	*macro_user[MAX_USER_MACROS];
+
 /** readlogs.c **/
 int		log_rotation_method = LOG_ROTATION_NONE;
 extern time_t	this_scheduled_log_rotation;
@@ -134,11 +139,12 @@ int		color_transparency_index_b = 255;
 
 int		status_show_long_plugin_output = FALSE;
 int		tac_show_only_hard_state = FALSE;
+int		extinfo_show_child_hosts = SHOW_CHILD_HOSTS_NONE;
 int		suppress_maintenance_downtime = FALSE;
 int		show_tac_header = TRUE;
 int		show_tac_header_pending = TRUE;
-int		showlog_initial_states = TRUE;
-int		showlog_current_states = TRUE;
+int		showlog_initial_states = FALSE;
+int		showlog_current_states = FALSE;
 int		tab_friendly_titles = FALSE;
 int		add_notif_num_hard = 0;
 int		add_notif_num_soft = 0;
@@ -147,6 +153,7 @@ int		week_starts_on_monday = FALSE;
 
 int		show_partial_hostgroups = FALSE;
 int		default_downtime_duration = 7200;
+int		default_expiring_acknowledgement_duration = 86400;
 
 extern hostgroup       *hostgroup_list;
 extern contactgroup    *contactgroup_list;
@@ -555,6 +562,9 @@ int read_cgi_config_file(char *filename) {
 		else if (!strcmp(var, "persistent_ack_comments"))
 			persistent_ack_comments = (atoi(val) > 0) ? TRUE : FALSE;
 
+		else if (!strcmp(var, "default_expiring_acknowledgement_duration"))
+			default_expiring_acknowledgement_duration = atoi(val);
+
 		else if (!strcmp(var, "lock_author_names"))
 			lock_author_names = (atoi(val) > 0) ? TRUE : FALSE;
 
@@ -570,6 +580,12 @@ int read_cgi_config_file(char *filename) {
 		else if (!strcmp(var, "tac_show_only_hard_state"))
 			tac_show_only_hard_state = (atoi(val) > 0) ? TRUE : FALSE;
 
+		else if (!strcmp(var, "extinfo_show_child_hosts")) {
+			if (atoi(val) == SHOW_CHILD_HOSTS_IMMEDIATE)
+				extinfo_show_child_hosts = SHOW_CHILD_HOSTS_IMMEDIATE;
+			else if (atoi(val) == SHOW_CHILD_HOSTS_ALL)
+				extinfo_show_child_hosts = SHOW_CHILD_HOSTS_ALL;
+		}
 		else if (!strcmp(var, "suppress_maintenance_downtime"))
 			suppress_maintenance_downtime = (atoi(val) > 0) ? TRUE : FALSE;
 
@@ -642,7 +658,15 @@ int read_main_config_file(char *filename) {
 
 		strip(input);
 
-		if (strstr(input, "interval_length=") == input) {
+                if (strstr(input, "resource_file=") == input) {
+                        temp_buffer = strtok(input, "=");
+                        temp_buffer = strtok(NULL, "\x0");
+                        strncpy(resource_file, (temp_buffer == NULL) ? "" : temp_buffer, sizeof(resource_file));
+                        resource_file[sizeof(resource_file)-1] = '\x0';
+                        strip(resource_file);
+                }
+
+		else if (strstr(input, "interval_length=") == input) {
 			temp_buffer = strtok(input, "=");
 			temp_buffer = strtok(NULL, "\x0");
 			interval_length = (temp_buffer == NULL) ? 60 : atoi(temp_buffer);
@@ -771,6 +795,86 @@ int read_all_status_data(char *config_file, int options) {
 }
 
 
+/* processes macros in resource file */
+int read_icinga_resource_file(char *resource_file) {
+        char *input = NULL;
+        char *variable = NULL;
+        char *value = NULL;
+        char *temp_ptr = NULL;
+        mmapfile *thefile = NULL;
+        int current_line = 1;
+        int error = FALSE;
+        int user_index = 0;
+
+        if ((thefile = mmap_fopen(resource_file)) == NULL) {
+                return ERROR;
+        }
+
+        /* process all lines in the resource file */
+        while (1) {
+
+                /* free memory */
+                my_free(input);
+
+                /* read the next line */
+                if ((input = mmap_fgets_multiline(thefile)) == NULL)
+                        break;
+
+                current_line = thefile->current_line;
+
+                /* skip blank lines and comments */
+                if (input[0] == '#' || input[0] == '\x0' || input[0] == '\n' || input[0] == '\r')
+                        continue;
+
+                strip(input);
+
+                /* get the variable name */
+                if ((temp_ptr = my_strtok(input, "=")) == NULL) {
+                        error = TRUE;
+                        break;
+                }
+                if ((variable = (char *)strdup(temp_ptr)) == NULL) {
+                        error = TRUE;
+                        break;
+                }
+
+                /* get the value */
+                if ((temp_ptr = my_strtok(NULL, "\n")) == NULL) {
+                        error = TRUE;
+                        break;
+                }
+                if ((value = (char *)strdup(temp_ptr)) == NULL) {
+                        error = TRUE;
+                        break;
+                }
+
+                /* what should we do with the variable/value pair? */
+
+                /* check for macro declarations */
+                if (variable[0] == '$' && variable[strlen(variable)-1] == '$') {
+
+                        /* $USERx$ macro declarations */
+                        if (strstr(variable, "$USER") == variable  && strlen(variable) > 5) {
+                                user_index = atoi(variable + 5) - 1;
+                                if (user_index >= 0 && user_index < MAX_USER_MACROS) {
+                                        my_free(macro_user[user_index]);
+                                        macro_user[user_index] = (char *)strdup(value);
+                                }
+                        }
+                }
+        }
+
+        /* free leftover memory and close the file */
+        my_free(input);
+        mmap_fclose(thefile);
+
+        if (error == TRUE)
+                return ERROR;
+
+        return OK;
+}
+
+
 /**********************************************************
  *************** COMMON HEADER AND FOOTER *****************
  **********************************************************/
@@ -1045,10 +1149,6 @@ void document_header(int cgi_id, int use_stylesheet) {
 
 		/* functions to handle the checkboxes and dropdown menus */
 		printf("<script type='text/javascript' src='%s%s'></script>\n", url_js_path, CHECKBOX_FUNCTIONS_JS);
-
-		/* include code for highlight table rows */
-		if (highlight_table_rows == TRUE)
-			printf("<script type='text/javascript' src='%s%s'></script>\n", url_js_path, HIGHLIGHT_TABLE_JS);
 	}
 
 	if (cgi_id == STATUSMAP_CGI_ID || cgi_id == TRENDS_CGI_ID) {
@@ -1785,6 +1885,11 @@ void display_info_table(char *title, int refresh, authdata *current_authdata, in
 			printf("<DIV CLASS='infoBoxBadProcStatus'>- Service checks are disabled</DIV>");
 	}
 
+	if (CGI_ID == CONFIG_CGI_ID && authorized_for_full_command_resolution(current_authdata)) {
+		if (access(resource_file, R_OK) != 0) 
+			printf("<DIV CLASS='infoBoxBadProcStatus'>Warning: Could not read resource file, raw command line could be incomplete!</DIV>");
+	}
+
 	/* must have missed 2 update intervals */
 	if (status_file_creation_time < (current_time - (2 * status_update_interval)))
 		printf("<DIV CLASS='infoBoxBadProcStatus'>Warning: Status data OUTDATED! Last status data update was %d seconds ago!</DIV>", (int)(current_time - status_file_creation_time));
@@ -2098,6 +2203,35 @@ void main_config_file_error(char *config_file) {
 	return;
 }
 
+/* displays an error if resource file could not be read */
+void icinga_resource_file_error(char *config_file) {
+
+        printf("<H1>Whoops!</H1>\n");
+
+        printf("<P><STRONG><FONT COLOR='RED'>Error: Could not open resource file '%s' for reading!</FONT></STRONG></P>\n", config_file);
+
+        printf("<P>\n");
+        printf("It seems that you enabled the cgis to read your local resource file (verify that in your cgi.cfg)\n");
+        printf("Here are some things you should check in order to resolve this error:\n");
+        printf("</P>\n");
+
+        printf("<P>\n");
+        printf("<OL>\n");
+
+        printf("<LI>Make sure you've installed the resource file in its proper location, defined in main config. A sample resource file (named <b>resource.cfg</b>) can be found in the <b>sample-config/</b> subdirectory of the %s source code distribution.\n", PROGRAM_NAME);
+        printf("<LI>Make sure the user your web server is running as has permission to read the resource file.\n");
+        printf("<LI>If you don't want to read your resource file (used e.g. for command expander in config.cgi) then disable it in cgi.cfg.\n");
+
+        printf("</OL>\n");
+        printf("</P>\n");
+
+        printf("<P>\n");
+        printf("Make sure you read the documentation on installing and configuring %s thoroughly before continuing.  If everything else fails, try sending a message to one of the mailing lists.  More information can be found at <a href='http://www.icinga.org'>http://www.icinga.org</a>.\n", PROGRAM_NAME);
+        printf("</P>\n");
+
+        return;
+}
+
 /* displays an error if object data could not be read */
 void object_data_error(void) {
 
@@ -2190,6 +2324,9 @@ void print_error(char *config_file, int error_type) {
 	case ERROR_CGI_MAIN_CFG:
 		main_config_file_error(config_file);
 		break;
+	case ERROR_CGI_RESOURCE_CFG:
+		icinga_resource_file_error(config_file);
+		break;
 	}
 
 	printf("</td></tr></table></DIV>\n");
