@@ -73,7 +73,9 @@ struct nagios_extcmd in_core_commands[] = {
 	CMD_DEF(SAVE_STATE_INFORMATION, 0, NULL),
 	CMD_DEF(READ_STATE_INFORMATION, 0, NULL),
 	CMD_DEF(ACKNOWLEDGE_HOST_PROBLEM, 0, NULL),
+	CMD_DEF(ACKNOWLEDGE_HOST_PROBLEM_EXPIRE, 0, NULL),
 	CMD_DEF(ACKNOWLEDGE_SVC_PROBLEM, 0, NULL),
+	CMD_DEF(ACKNOWLEDGE_SVC_PROBLEM_EXPIRE, 0, NULL),
 	CMD_DEF(START_EXECUTING_SVC_CHECKS, 0, NULL),
 	CMD_DEF(STOP_EXECUTING_SVC_CHECKS, 0, NULL),
 	CMD_DEF(START_ACCEPTING_PASSIVE_SVC_CHECKS, 0, NULL),
