@@ -140,6 +140,8 @@ extern "C" {
 
 #define DEFAULT_STALKING_EVENT_HANDLERS_FOR_HOSTS               0       /* by default do not run event handlers for stalked hosts */
 #define DEFAULT_STALKING_EVENT_HANDLERS_FOR_SERVICES            0       /* by default do not run event handlers for stalked services */
+#define DEFAULT_STALKING_NOTIFICATIONS_FOR_HOSTS               	0       /* by default do not run notifications for stalked hosts */
+#define DEFAULT_STALKING_NOTIFICATIONS_FOR_SERVICES            	0       /* by default do not run notifications for stalked services */
 
 #define DEFAULT_ADDITIONAL_FRESHNESS_LATENCY			15	/* seconds to be added to freshness thresholds when automatically calculated by Icinga */
 
@@ -209,6 +211,7 @@ extern "C" {
 #define NOTIFICATION_DOWNTIMEEND        6
 #define NOTIFICATION_DOWNTIMECANCELLED  7
 #define NOTIFICATION_CUSTOM             99
+#define NOTIFICATION_STALKING		16211	
 
 
 
@@ -252,6 +255,7 @@ extern "C" {
 #define EVENT_HFRESHNESS_CHECK          13      /* checks host result "freshness" */
 #define EVENT_RESCHEDULE_CHECKS		14      /* adjust scheduling of host and service checks */
 #define EVENT_EXPIRE_COMMENT            15      /* removes expired comments */
+#define EVENT_EXPIRE_ACKNOWLEDGEMENT    16      /* removes expired acknowledgements */
 #define EVENT_SLEEP                     98      /* asynchronous sleep event that occurs when event queues are empty */
 #define EVENT_USER_FUNCTION             99      /* USER-defined function (modules) */
 
@@ -552,8 +556,8 @@ int should_host_notification_be_escalated(host *);				/* checks if a host notifi
 int host_notification(host *,int,char *,char *,int);                           	/* notify all contacts about a host (problem or recovery) */
 int check_contact_host_notification_viability(contact *,host *,int,int);	/* checks viability of notifying a contact about a host */
 int notify_contact_of_host(icinga_macros *mac, contact *,host *,int,char *,char *,int,int);        	/* notify a single contact about a host */
-int create_notification_list_from_host(icinga_macros *mac, host *,int,int *);         		/* given a host, create list of contacts to be notified (remove duplicates) */
-int create_notification_list_from_service(icinga_macros *mac, service *,int,int *);    		/* given a service, create list of contacts to be notified (remove duplicates) */
+int create_notification_list_from_host(icinga_macros *mac, host *,int,int *,int);         		/* given a host, create list of contacts to be notified (remove duplicates) */
+int create_notification_list_from_service(icinga_macros *mac, service *,int,int *,int);    		/* given a service, create list of contacts to be notified (remove duplicates) */
 int add_notification(icinga_macros *mac, contact *);						/* adds a notification instance */
 notification *find_notification(contact *);					/* finds a notification object */
 time_t get_next_host_notification_time(host *,time_t);				/* calculates nex acceptable re-notification time for a host */
@@ -663,8 +667,8 @@ void disable_host_notifications(host *);		/* disables host notifications */
 void enable_and_propagate_notifications(host *,int,int,int,int);	/* enables notifications for all hosts and services beyond a given host */
 void disable_and_propagate_notifications(host *,int,int,int,int);	/* disables notifications for all hosts and services beyond a given host */
 void schedule_and_propagate_downtime(host *,time_t,char *,char *,time_t,time_t,int,unsigned long,unsigned long); /* schedules downtime for all hosts beyond a given host */
-void acknowledge_host_problem(host *,char *,char *,int,int,int);	/* acknowledges a host problem */
-void acknowledge_service_problem(service *,char *,char *,int,int,int);	/* acknowledges a service problem */
+void acknowledge_host_problem(host *,char *,char *,int,int,int,time_t);	/* acknowledges a host problem */
+void acknowledge_service_problem(service *,char *,char *,int,int,int,time_t);	/* acknowledges a service problem */
 void remove_host_acknowledgement(host *);		/* removes a host acknowledgement */
 void remove_service_acknowledgement(service *);		/* removes a service acknowledgement */
 void start_executing_service_checks(void);		/* starts executing service checks */
@@ -729,6 +733,8 @@ char *get_program_version(void);
 char *get_program_modification_date(void);
 int has_shell_metachars(const char *);
 
+extern pthread_mutex_t icinga_eventloop_lock;
+
 
 #ifdef __cplusplus
 }
