@@ -20,14 +20,21 @@ class IcingaApiCommandCollection
 		
 	// TODO: add missing commands
 	private $commandFields = array (
+	
+		/*
+		 * Downtimes
+		 */
+		'DEL_HOST_DOWNTIME'						=> array(self::COMMAND_DOWNTIME_ID),
+		'DEL_SVC_DOWNTIME'						=> array(self::COMMAND_DOWNTIME_ID),
+	
 		/*
 		 * SERVICE COMMANDS
 		 */
-		// Put this in a downtime view
-		// 'DEL_SVC_DOWNTIME'						=> array(self::COMMAND_HOST, self::COMMAND_SERVICE, self::COMMAND_ID),
 		'SET_SVC_NOTIFICATION_NUMBER'			=> array(self::COMMAND_HOST, self::COMMAND_SERVICE, self::COMMAND_DATA),
 		'SCHEDULE_SVC_CHECK'					=> array(self::COMMAND_HOST, self::COMMAND_SERVICE, self::COMMAND_CHECKTIME),
+		'SCHEDULE_FORCED_SVC_CHECK'				=> array(self::COMMAND_HOST, self::COMMAND_SERVICE, self::COMMAND_CHECKTIME),
 		'ACKNOWLEDGE_SVC_PROBLEM'				=> array(self::COMMAND_HOST, self::COMMAND_SERVICE, self::COMMAND_STICKY, self::COMMAND_NOTIFY, self::COMMAND_PERSISTENT, self::COMMAND_AUTHOR, self::COMMAND_COMMENT),
+		'REMOVE_SVC_ACKNOWLEDGEMENT'            		=> array(self::COMMAND_HOST, self::COMMAND_SERVICE),
 		'SCHEDULE_SVC_DOWNTIME'					=> array(self::COMMAND_HOST, self::COMMAND_SERVICE, self::COMMAND_STARTTIME, self::COMMAND_ENDTIME, self::COMMAND_FIXED, self::COMMAND_DATA, self::COMMAND_DURATION, self::COMMAND_AUTHOR, self::COMMAND_COMMENT),
 		'PROCESS_SERVICE_CHECK_RESULT'			=> array(self::COMMAND_HOST, self::COMMAND_SERVICE, self::COMMAND_RETURN_CODE, self::COMMAND_OUTPUT, self::COMMAND_PERFDATA),
 		'ADD_SVC_COMMENT'						=> array(self::COMMAND_HOST, self::COMMAND_SERVICE, self::COMMAND_DATA, self::COMMAND_AUTHOR, self::COMMAND_COMMENT),
@@ -52,13 +59,13 @@ class IcingaApiCommandCollection
 		/*
 		 * HOST COMMANDS
 		 */
-		// This have to be in a downtime view
-		// 'DEL_HOST_DOWNTIME'						=> array(self::COMMAND_HOST, self::COMMAND_ID),
 		'SCHEDULE_HOST_CHECK'					=> array(self::COMMAND_HOST, self::COMMAND_CHECKTIME),
+		'SCHEDULE_FORCED_HOST_CHECK'			=> array(self::COMMAND_HOST, self::COMMAND_CHECKTIME),
 		'SCHEDULE_HOST_DOWNTIME'				=> array(self::COMMAND_HOST, self::COMMAND_STARTTIME, self::COMMAND_ENDTIME, self::COMMAND_FIXED, self::COMMAND_DATA, self::COMMAND_DURATION, self::COMMAND_AUTHOR, self::COMMAND_COMMENT),	
 		'SCHEDULE_HOST_SVC_DOWNTIME'			=> array(self::COMMAND_HOST, self::COMMAND_STARTTIME, self::COMMAND_ENDTIME, self::COMMAND_FIXED, self::COMMAND_DATA, self::COMMAND_DURATION, self::COMMAND_AUTHOR, self::COMMAND_COMMENT),
 		'PROCESS_HOST_CHECK_RESULT'				=> array(self::COMMAND_HOST, self::COMMAND_RETURN_CODE, self::COMMAND_OUTPUT, self::COMMAND_PERFDATA),
 		'ACKNOWLEDGE_HOST_PROBLEM'				=> array(self::COMMAND_HOST, self::COMMAND_STICKY, self::COMMAND_NOTIFY, self::COMMAND_PERSISTENT, self::COMMAND_AUTHOR, self::COMMAND_COMMENT),
+		'REMOVE_HOST_ACKNOWLEDGEMENT'           		=> array(self::COMMAND_HOST),
 		'ADD_HOST_COMMENT'						=> array(self::COMMAND_HOST, self::COMMAND_DATA, self::COMMAND_AUTHOR, self::COMMAND_COMMENT),
 		'DISABLE_HOST_CHECK'					=> array(self::COMMAND_HOST),
 		'ENABLE_HOST_CHECK'						=> array(self::COMMAND_HOST),
@@ -177,7 +184,7 @@ class IcingaApiCommandCollection
 			'required'	=> false
 		),
 		self::COMMAND_DURATION => array(
-			'type'	=> 'text',
+			'type'	=> 'duration',
 			'required'	=> false
 		),
 		self::COMMAND_DATA => array(
@@ -188,7 +195,11 @@ class IcingaApiCommandCollection
 		self::COMMAND_NOTIFICATION_OPTIONS => array (
 			'type'	=> 'notification_options',
 			'required' => true
-		)
+		),
+		self::COMMAND_DOWNTIME_ID => array(
+			'type'	=> 'ro',
+			'required'	=> true
+		),
 	);
 
 	private $commands = array (
@@ -422,4 +433,4 @@ class IcingaApiCommandCollection
 // class exceptions
 class IcingaApiCommandCollectionException extends IcingaApiCommandException {}
 
-?>
\ No newline at end of file
+?>
