@@ -15,6 +15,7 @@ class IcingaApiSearchIdoPgsql
 
 	public $tablePrefix = 'icinga_';
 	public $postProcess = false;
+	public $configType = 1;
 	public $groupByCols = array();
 	public $clearVariables = array();
 	public $hasArithmeticField = false;
@@ -55,7 +56,7 @@ class IcingaApiSearchIdoPgsql
 			${if_table:cvsh,oh:inner join ${TABLE_PREFIX}customvariablestatus AS cvsh on oh.object_id = cvsh.object_id}
 			${if_table:cvsc,oc,cgm,cg,hcg,h:inner join ${TABLE_PREFIX}customvariablestatus AS cvsc on oc.object_id = cvsc.object_id}
 			where
-				oh.objecttype_id = 1
+				oh.objecttype_id = 1 and h.config_type=${CONFIG_TYPE}
 			${FILTER_AND}
 			${GROUPBY}
 			${ORDERBY}
@@ -74,18 +75,19 @@ class IcingaApiSearchIdoPgsql
 			inner join ${TABLE_PREFIX}servicestatus AS ss on ss.service_object_id = os.object_id
 			${if_table:ocg,scg,s:inner join ${TABLE_PREFIX}objects AS ocg on ocg.object_id = scg.contactgroup_object_id and ocg.objecttype_id = 11}
 			${if_table:hs,s:inner join ${TABLE_PREFIX}hoststatus AS hs on hs.host_object_id = s.host_object_id}
+			${if_table:h:inner join ${TABLE_PREFIX}hosts h on h.host_object_id = s.host_object_id}
 			${if_table:oh,s:inner join ${TABLE_PREFIX}objects AS oh on oh.object_id = s.host_object_id and oh.objecttype_id = 1}
 			${if_table:sgm:left join ${TABLE_PREFIX}servicegroup_members AS sgm on sgm.service_object_id = os.object_id}
 			${if_table:sg,sgm:left join ${TABLE_PREFIX}servicegroups AS sg on sg.servicegroup_id = sgm.servicegroup_id}
 			${if_table:osg,sg,sgm:left join ${TABLE_PREFIX}objects AS osg on osg.object_id = sg.servicegroup_object_id}
 			${if_table:hgm,oh,s:inner join ${TABLE_PREFIX}hostgroup_members AS hgm on hgm.host_object_id = oh.object_id}
 			${if_table:hg,hgm,oh,s:inner join ${TABLE_PREFIX}hostgroups AS hg on hg.hostgroup_id = hgm.hostgroup_id}
-			${if_table:ohg,hg,hgm,oh,s:inner join ${TABLE_PREFIX}objects ohg AS on ohg.object_id = hg.hostgroup_object_id}
+			${if_table:ohg,hg,hgm,oh,s:inner join ${TABLE_PREFIX}objects AS ohg on ohg.object_id = hg.hostgroup_object_id}
 			${if_table:cvsh,oh,s:inner join ${TABLE_PREFIX}customvariablestatus AS cvsh on oh.object_id = cvsh.object_id}
 			${if_table:cvss:inner join ${TABLE_PREFIX}customvariablestatus AS cvss on os.object_id = cvss.object_id}
 			${if_table:cvsc,oc,cgm,cg,scg,s:inner join ${TABLE_PREFIX}customvariablestatus AS cvsc on oc.object_id = cvsc.object_id}
 			where
-				os.objecttype_id = 2
+				os.objecttype_id = 2 and s.config_type=${CONFIG_TYPE}
 			${FILTER_AND}
 			${GROUPBY}
 			${ORDERBY}
@@ -181,13 +183,14 @@ class IcingaApiSearchIdoPgsql
 				${FIELDS}
 			from
 				${TABLE_PREFIX}logentries AS le
+				${if_table:i:inner join ${TABLE_PREFIX}instances i on i.instance_id = le.instance_id}
 			${FILTER}
 			${GROUPBY}
 			${ORDERBY}
 			${LIMIT}',
 		self::TARGET_HOST_STATUS_SUMMARY => 
 			'select
-				${FIELDS:hs.current_state AS HOST_STATE, count(hs.current_state) AS COUNT}
+				${FIELDS:hs.current_state AS HOST_STATE, count(DISTINCT hs.host_object_id) AS COUNT}
 			from
 				${TABLE_PREFIX}hoststatus AS hs
 			inner join ${TABLE_PREFIX}objects AS oh on oh.object_id = hs.host_object_id
@@ -203,14 +206,15 @@ class IcingaApiSearchIdoPgsql
 			${if_table:ohg,hg,hgm,oh:inner join ${TABLE_PREFIX}objects AS ohg on ohg.object_id = hg.hostgroup_object_id}
 			${if_table:cvsh,oh:inner join ${TABLE_PREFIX}customvariablestatus AS cvsh on oh.object_id = cvsh.object_id}
 			${if_table:cvsc,oc,cgm,cg,hcg,h,oh:-- inner join ${TABLE_PREFIX}customvariablestatus AS cvsc on oc.object_id = cvsc.object_id}
-			${FILTER}
+			where h.config_type=${CONFIG_TYPE}
+			${FILTER_AND}
 			group by
 				hs.current_state
 			${ORDERBY:hs.current_state}
 			${LIMIT}',
 		self::TARGET_SERVICE_STATUS_SUMMARY =>
 			'select
-				${FIELDS:ss.current_state AS SERVICE_STATE, count(ss.current_state) AS COUNT}
+				${FIELDS:ss.current_state AS SERVICE_STATE, count(DISTINCT ss.service_object_id) AS COUNT}
 			from
 				${TABLE_PREFIX}servicestatus AS ss
 			inner join ${TABLE_PREFIX}objects AS os on os.object_id = ss.service_object_id
@@ -229,7 +233,8 @@ class IcingaApiSearchIdoPgsql
 			${if_table:cvsh,oh,s,os:inner join ${TABLE_PREFIX}customvariablestatus AS cvsh on oh.object_id = cvsh.object_id}
 			${if_table:cvss,os:inner join ${TABLE_PREFIX}customvariablestatus AS cvss on os.object_id = cvss.object_id}
 			${if_table:cvsc,oc,cgm,cg,scg,s,os:-- inner join ${TABLE_PREFIX}customvariablestatus AS cvsc on oc.object_id = cvsc.object_id}
-			${FILTER}
+			where s.config_type=${CONFIG_TYPE}
+			${FILTER_AND}
 			group by
 				ss.current_state
 			${ORDERBY:ss.current_state}
@@ -298,7 +303,7 @@ class IcingaApiSearchIdoPgsql
 			from
 				${TABLE_PREFIX}notifications AS n
 			inner join ${TABLE_PREFIX}objects AS obn on obn.object_id = n.object_id and obn.is_active = 1
-			${if_table:s,on:left join ${TABLE_PREFIX}service ASs s on s.service_object_id = obn.object_id}
+			${if_table:s,on:left join ${TABLE_PREFIX}service AS s on s.service_object_id = obn.object_id}
 			${if_table:h,s,on:left join ${TABLE_PREFIX}hosts AS h on h.host_object_id = obn.object_id or h.host_object_id = s.host_object_id}
 			${if_table:oh,h,s,on:left join ${TABLE_PREFIX}objects AS oh on oh.object_id = h.host_object_id}
 			${if_table:os,s,on:left join ${TABLE_PREFIX}objects AS os on os.object_id = s.service_object_id}
@@ -405,6 +410,64 @@ class IcingaApiSearchIdoPgsql
 			${FILTER_AND}
 			${GROUPBY}
 			${ORDERBY}
+			${LIMIT}',
+		
+		self::TARGET_DOWNTIMEHISTORY => 
+			'select
+				distinct ${FIELDS}
+			from
+			${TABLE_PREFIX}downtimehistory AS dth
+			
+			left join ${TABLE_PREFIX}objects AS os ON os.object_id = dth.object_id
+			left join ${TABLE_PREFIX}services AS s ON s.service_object_id = os.object_id
+			${if_table:ss:left join ${TABLE_PREFIX}servicestatus ss on ss.service_object_id = os.object_id}
+			
+			left join ${TABLE_PREFIX}objects AS oh ON oh.object_id = s.host_object_id OR oh.object_id = dth.object_id
+			${if_table:h:inner join ${TABLE_PREFIX}hosts h on h.host_object_id = oh.object_id}
+			${if_table:hs:inner join ${TABLE_PREFIX}hoststatus hs on hs.host_object_id = oh.object_id}
+			
+			${if_table:hgm:left join ${TABLE_PREFIX}hostgroup_members AS hgm ON hgm.host_object_id = oh.object_id}
+			${if_table:hg,hgm:left join ${TABLE_PREFIX}hostgroups AS hg ON hg.hostgroup_id = hgm.hostgroup_id}
+			${if_table:ohg,hg,hgm:left join ${TABLE_PREFIX}objects AS ohg ON ohg.object_id = hg.hostgroup_object_id}
+			
+			${if_table:sgm:left join ${TABLE_PREFIX}servicegroup_members sgm on sgm.service_object_id = os.object_id}
+			${if_table:sg,sgm:left join ${TABLE_PREFIX}servicegroups sg on sg.servicegroup_id = sgm.servicegroup_id}
+			${if_table:osg,sg,sgm:left join ${TABLE_PREFIX}objects osg on osg.object_id = sg.servicegroup_object_id}
+			
+			${if_table:i,dth:left join ${TABLE_PREFIX}instances i on i.instance_id = dth.instance_id}
+			
+			${FILTER}
+			${GROUPBY}
+			${ORDERBY}
+			${LIMIT}',
+		
+		self::TARGET_DOWNTIME => 
+			'select
+				distinct ${FIELDS}
+			from
+			${TABLE_PREFIX}scheduleddowntime AS dt
+			
+			left join ${TABLE_PREFIX}objects AS os ON os.object_id = dt.object_id
+			left join ${TABLE_PREFIX}services AS s ON s.service_object_id = os.object_id
+			${if_table:ss:left join ${TABLE_PREFIX}servicestatus ss on ss.service_object_id = os.object_id}
+			
+			left join ${TABLE_PREFIX}objects AS oh ON oh.object_id = s.host_object_id OR oh.object_id = dt.object_id
+			${if_table:h:inner join ${TABLE_PREFIX}hosts h on h.host_object_id = oh.object_id}
+			${if_table:hs:inner join ${TABLE_PREFIX}hoststatus hs on hs.host_object_id = oh.object_id}
+			
+			${if_table:hgm:left join ${TABLE_PREFIX}hostgroup_members AS hgm ON hgm.host_object_id = oh.object_id}
+			${if_table:hg,hgm:left join ${TABLE_PREFIX}hostgroups AS hg ON hg.hostgroup_id = hgm.hostgroup_id}
+			${if_table:ohg,hg,hgm:left join ${TABLE_PREFIX}objects AS ohg ON ohg.object_id = hg.hostgroup_object_id}
+			
+			${if_table:sgm:left join ${TABLE_PREFIX}servicegroup_members sgm on sgm.service_object_id = os.object_id}
+			${if_table:sg,sgm:left join ${TABLE_PREFIX}servicegroups sg on sg.servicegroup_id = sgm.servicegroup_id}
+			${if_table:osg,sg,sgm:left join ${TABLE_PREFIX}objects osg on osg.object_id = sg.servicegroup_object_id}
+			
+			${if_table:i,dt:left join ${TABLE_PREFIX}instances i on i.instance_id = dt.instance_id}
+			
+			${FILTER}
+			${GROUPBY}
+			${ORDERBY}
 			${LIMIT}'
 		);
 			// COLUMNS
@@ -472,7 +535,9 @@ class IcingaApiSearchIdoPgsql
 		'HOST_NAME' => array('oh', 'name1'),
 		'HOST_ALIAS' => array('h', 'alias'),
 		'HOST_DISPLAY_NAME' => array('h', 'display_name'),
+		'HOST_ADDRESS6' => array('h', 'address6'),
 		'HOST_ADDRESS' => array('h', 'address'),
+		'HOST_ADRESS6' => array('h', 'address6'),
 		'HOST_ACTIVE_CHECKS_ENABLED' => array('h', 'active_checks_enabled'),
 		'HOST_CONFIG_TYPE' => array('h', 'config_type'),
 		'HOST_FLAP_DETECTION_ENABLED' => array('hs', 'flap_detection_enabled'),
@@ -530,7 +595,7 @@ class IcingaApiSearchIdoPgsql
 		'HOST_CHILD_NAME' => array('oh', 'name1'),
 		'HOST_CUSTOMVARIABLE_NAME' => array('cvsh', 'varname'),
 		'HOST_CUSTOMVARIABLE_VALUE' => array('cvsh', 'varvalue'),
-		'HOST_IS_PENDING' => array('hs','has_been_checked','(%s-hs.should_be_scheduled)*-1'),
+		'HOST_IS_PENDING' => array('hs','has_been_checked','(%s-hs.should_be_scheduled)*-1>0'),
 
 		// Service data
 		'SERVICE_ID' => array('s', 'service_id'),
@@ -587,7 +652,7 @@ class IcingaApiSearchIdoPgsql
 		'SERVICE_CUSTOMVARIABLE_NAME' => array('cvss', 'varname'),
 		'SERVICE_CUSTOMVARIABLE_VALUE' => array('cvss', 'varvalue'),
 		'SERVICE_STATE_COUNT' => array('count(ss', 'current_state)'),
-		'SERVICE_IS_PENDING' => array('ss','has_been_checked','(%s-ss.should_be_scheduled)*-1'),
+		'SERVICE_IS_PENDING' => array('ss','has_been_checked','(%s-ss.should_be_scheduled)*-1>0'),
 
 		// Config vars
 		'CONFIG_VAR_ID' => array('cfv', 'configfilevariable_id'),
@@ -658,7 +723,46 @@ class IcingaApiSearchIdoPgsql
 		'COMMENT_IS_PERSISTENT' => array('co', 'is_persistent'),
 		'COMMENT_SOURCE' => array('co', 'comment_source'),
 		'COMMENT_EXPIRES' => array('co', 'expires'),
-		'COMMENT_EXPIRATION_TIME' => array('co', 'expiration_time')
+		'COMMENT_EXPIRATION_TIME' => array('co', 'expiration_time'),
+	
+			// Downtimehistory
+		'DOWNTIMEHISTORY_ID' => array ('dthh', 'downtimehistory_id'),
+		'DOWNTIMEHISTORY_INSTANCE_ID' => array ('dth', 'instance_id'),
+		'DOWNTIMEHISTORY_DOWNTIME_TYPE' => array ('dth', 'downtime_type'),
+		'DOWNTIMEHISTORY_OBJECT_ID' => array ('dth', 'object_id'),
+		'DOWNTIMEHISTORY_ENTRY_TIME' => array ('dth', 'entry_time'),
+		'DOWNTIMEHISTORY_AUTHOR_NAME' => array ('dth', 'author_name'),
+		'DOWNTIMEHISTORY_COMMENT_DATA' => array ('dth', 'comment_data'),
+		'DOWNTIMEHISTORY_INTERNAL_DOWNTIME_ID' => array ('dth', 'internal_downtime_id'),
+		'DOWNTIMEHISTORY_TRIGGERED_BY_ID' => array ('dth', 'triggered_by_id'),
+		'DOWNTIMEHISTORY_IS_FIXED' => array ('dth', 'is_fixed'),
+		'DOWNTIMEHISTORY_DURATION' => array ('dth', 'duration'),
+		'DOWNTIMEHISTORY_SCHEDULED_START_TIME' => array ('dth', 'scheduled_start_time'),
+		'DOWNTIMEHISTORY_SCHEDULED_END_TIME' => array ('dth', 'scheduled_end_time'),
+		'DOWNTIMEHISTORY_WAS_STARTED' => array ('dth', 'was_started'),
+		'DOWNTIMEHISTORY_ACTUAL_START_TIME' => array ('dth', 'actual_start_time'),
+		'DOWNTIMEHISTORY_ACTUAL_START_TIME_USEC' => array ('dth', 'actual_start_time_usec'),
+		'DOWNTIMEHISTORY_ACTUAL_END_TIME' => array ('dth', 'actual_end_time'),
+		'DOWNTIMEHISTORY_ACTUAL_END_TIME_USEC' => array ('dth', 'actual_end_time_usec'),
+		'DOWNTIMEHISTORY_WAS_CANCELLED' => array ('dth', 'was_cancelled'),
+		
+			// Downtime
+		'DOWNTIME_ID' => array ('dt', 'scheduleddowntime_id'),
+		'DOWNTIME_INSTANCE_ID' => array ('dt', 'instance_id'),
+		'DOWNTIME_DOWNTIME_TYPE' => array ('dt', 'downtime_type'),
+		'DOWNTIME_OBJECT_ID' => array ('dt', 'object_id'),
+		'DOWNTIME_ENTRY_TIME' => array ('dt', 'entry_time'),
+		'DOWNTIME_AUTHOR_NAME' => array ('dt', 'author_name'),
+		'DOWNTIME_COMMENT_DATA' => array ('dt', 'comment_data'),
+		'DOWNTIME_INTERNAL_DOWNTIME_ID' => array ('dt', 'internal_downtime_id'),
+		'DOWNTIME_TRIGGERED_BY_ID' => array ('dt', 'triggered_by_id'),
+		'DOWNTIME_IS_FIXED' => array ('dt', 'is_fixed'),
+		'DOWNTIME_DURATION' => array ('dt', 'duration'),
+		'DOWNTIME_SCHEDULED_START_TIME' => array ('dt', 'scheduled_start_time'),
+		'DOWNTIME_SCHEDULED_END_TIME' => array ('dt', 'scheduled_end_time'),
+		'DOWNTIME_WAS_STARTED' => array ('dt', 'was_started'),
+		'DOWNTIME_ACTUAL_START_TIME' => array ('dt', 'actual_start_time'),
+		'DOWNTIME_ACTUAL_START_TIME_USEC' => array ('dt', 'actual_start_time_usec')
 		);
 
 	/*
@@ -744,4 +848,4 @@ class IcingaApiSearchIdoPgsql
 
 }
 
-?>
\ No newline at end of file
+?>
