@@ -28,7 +28,7 @@ SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";
 CREATE TABLE IF NOT EXISTS icinga_acknowledgements (
   acknowledgement_id serial,
   instance_id bigint unsigned default 0,
-  entry_time datetime  default '0000-00-00 00:00:00',
+  entry_time timestamp  default '0000-00-00 00:00:00',
   entry_time_usec  int default 0,
   acknowledgement_type smallint default 0,
   object_id bigint unsigned default 0,
@@ -38,6 +38,7 @@ CREATE TABLE IF NOT EXISTS icinga_acknowledgements (
   is_sticky smallint default 0,
   persistent_comment smallint default 0,
   notify_contacts smallint default 0,
+  end_time timestamp default '0000-00-00 00:00:00',
   PRIMARY KEY  (acknowledgement_id)
 ) ENGINE=InnoDB COMMENT='Current and historical host and service acknowledgements';
 
@@ -66,20 +67,20 @@ CREATE TABLE IF NOT EXISTS icinga_commands (
 CREATE TABLE IF NOT EXISTS icinga_commenthistory (
   commenthistory_id serial,
   instance_id bigint unsigned default 0,
-  entry_time datetime  default '0000-00-00 00:00:00',
+  entry_time timestamp  default '0000-00-00 00:00:00',
   entry_time_usec  int default 0,
   comment_type smallint default 0,
   entry_type smallint default 0,
   object_id bigint unsigned default 0,
-  comment_time datetime  default '0000-00-00 00:00:00',
+  comment_time timestamp  default '0000-00-00 00:00:00',
   internal_comment_id bigint unsigned default 0,
   author_name varchar(64) character set latin1  default '',
   comment_data varchar(255) character set latin1  default '',
   is_persistent smallint default 0,
   comment_source smallint default 0,
   expires smallint default 0,
-  expiration_time datetime  default '0000-00-00 00:00:00',
-  deletion_time datetime  default '0000-00-00 00:00:00',
+  expiration_time timestamp  default '0000-00-00 00:00:00',
+  deletion_time timestamp  default '0000-00-00 00:00:00',
   deletion_time_usec  int default 0,
   PRIMARY KEY  (commenthistory_id),
   UNIQUE KEY instance_id (instance_id,comment_time,internal_comment_id)
@@ -94,19 +95,19 @@ CREATE TABLE IF NOT EXISTS icinga_commenthistory (
 CREATE TABLE IF NOT EXISTS icinga_comments (
   comment_id serial,
   instance_id bigint unsigned default 0,
-  entry_time datetime  default '0000-00-00 00:00:00',
+  entry_time timestamp  default '0000-00-00 00:00:00',
   entry_time_usec  int default 0,
   comment_type smallint default 0,
   entry_type smallint default 0,
   object_id bigint unsigned default 0,
-  comment_time datetime  default '0000-00-00 00:00:00',
+  comment_time timestamp  default '0000-00-00 00:00:00',
   internal_comment_id bigint unsigned default 0,
   author_name varchar(64) character set latin1  default '',
   comment_data varchar(255) character set latin1  default '',
   is_persistent smallint default 0,
   comment_source smallint default 0,
   expires smallint default 0,
-  expiration_time datetime  default '0000-00-00 00:00:00',
+  expiration_time timestamp  default '0000-00-00 00:00:00',
   PRIMARY KEY  (comment_id),
   UNIQUE KEY instance_id (instance_id,comment_time,internal_comment_id)
 ) ENGINE=InnoDB  COMMENT='Usercomments on Icinga objects';
@@ -151,15 +152,15 @@ CREATE TABLE IF NOT EXISTS icinga_conninfo (
   conninfo_id serial,
   instance_id bigint unsigned default 0,
   agent_name varchar(32) character set latin1  default '',
-  agent_version varchar(8) character set latin1  default '',
+  agent_version varchar(16) character set latin1  default '',
   disposition varchar(16) character set latin1  default '',
   connect_source varchar(16) character set latin1  default '',
   connect_type varchar(16) character set latin1  default '',
-  connect_time datetime  default '0000-00-00 00:00:00',
-  disconnect_time datetime  default '0000-00-00 00:00:00',
-  last_checkin_time datetime  default '0000-00-00 00:00:00',
-  data_start_time datetime  default '0000-00-00 00:00:00',
-  data_end_time datetime  default '0000-00-00 00:00:00',
+  connect_time timestamp  default '0000-00-00 00:00:00',
+  disconnect_time timestamp  default '0000-00-00 00:00:00',
+  last_checkin_time timestamp  default '0000-00-00 00:00:00',
+  data_start_time timestamp  default '0000-00-00 00:00:00',
+  data_end_time timestamp  default '0000-00-00 00:00:00',
   bytes_processed bigint unsigned  default '0',
   lines_processed bigint unsigned  default '0',
   entries_processed bigint unsigned  default '0',
@@ -206,9 +207,9 @@ CREATE TABLE IF NOT EXISTS icinga_contactnotificationmethods (
   contactnotificationmethod_id serial,
   instance_id bigint unsigned default 0,
   contactnotification_id bigint unsigned default 0,
-  start_time datetime  default '0000-00-00 00:00:00',
+  start_time timestamp  default '0000-00-00 00:00:00',
   start_time_usec  int default 0,
-  end_time datetime  default '0000-00-00 00:00:00',
+  end_time timestamp  default '0000-00-00 00:00:00',
   end_time_usec  int default 0,
   command_object_id bigint unsigned default 0,
   command_args varchar(255) character set latin1  default '',
@@ -227,9 +228,9 @@ CREATE TABLE IF NOT EXISTS icinga_contactnotifications (
   instance_id bigint unsigned default 0,
   notification_id bigint unsigned default 0,
   contact_object_id bigint unsigned default 0,
-  start_time datetime  default '0000-00-00 00:00:00',
+  start_time timestamp  default '0000-00-00 00:00:00',
   start_time_usec  int default 0,
-  end_time datetime  default '0000-00-00 00:00:00',
+  end_time timestamp  default '0000-00-00 00:00:00',
   end_time_usec  int default 0,
   PRIMARY KEY  (contactnotification_id),
   UNIQUE KEY instance_id (instance_id,contact_object_id,start_time,start_time_usec)
@@ -279,11 +280,11 @@ CREATE TABLE IF NOT EXISTS icinga_contactstatus (
   contactstatus_id serial,
   instance_id bigint unsigned default 0,
   contact_object_id bigint unsigned default 0,
-  status_update_time datetime  default '0000-00-00 00:00:00',
+  status_update_time timestamp  default '0000-00-00 00:00:00',
   host_notifications_enabled smallint default 0,
   service_notifications_enabled smallint default 0,
-  last_host_notification datetime  default '0000-00-00 00:00:00',
-  last_service_notification datetime  default '0000-00-00 00:00:00',
+  last_host_notification timestamp  default '0000-00-00 00:00:00',
+  last_service_notification timestamp  default '0000-00-00 00:00:00',
   modified_attributes  int default 0,
   modified_host_attributes  int default 0,
   modified_service_attributes  int default 0,
@@ -353,7 +354,7 @@ CREATE TABLE IF NOT EXISTS icinga_customvariablestatus (
   customvariablestatus_id serial,
   instance_id bigint unsigned default 0,
   object_id bigint unsigned default 0,
-  status_update_time datetime  default '0000-00-00 00:00:00',
+  status_update_time timestamp  default '0000-00-00 00:00:00',
   has_been_modified smallint default 0,
   varname varchar(255) character set latin1  default '',
   varvalue varchar(255) character set latin1  default '',
@@ -387,19 +388,19 @@ CREATE TABLE IF NOT EXISTS icinga_downtimehistory (
   instance_id bigint unsigned default 0,
   downtime_type smallint default 0,
   object_id bigint unsigned default 0,
-  entry_time datetime  default '0000-00-00 00:00:00',
+  entry_time timestamp  default '0000-00-00 00:00:00',
   author_name varchar(64) character set latin1  default '',
   comment_data varchar(255) character set latin1  default '',
   internal_downtime_id bigint unsigned default 0,
   triggered_by_id bigint unsigned default 0,
   is_fixed smallint default 0,
   duration smallint default 0,
-  scheduled_start_time datetime  default '0000-00-00 00:00:00',
-  scheduled_end_time datetime  default '0000-00-00 00:00:00',
+  scheduled_start_time timestamp  default '0000-00-00 00:00:00',
+  scheduled_end_time timestamp  default '0000-00-00 00:00:00',
   was_started smallint default 0,
-  actual_start_time datetime  default '0000-00-00 00:00:00',
+  actual_start_time timestamp  default '0000-00-00 00:00:00',
   actual_start_time_usec  int default 0,
-  actual_end_time datetime  default '0000-00-00 00:00:00',
+  actual_end_time timestamp  default '0000-00-00 00:00:00',
   actual_end_time_usec  int default 0,
   was_cancelled smallint default 0,
   PRIMARY KEY  (downtimehistory_id),
@@ -419,9 +420,9 @@ CREATE TABLE IF NOT EXISTS icinga_eventhandlers (
   object_id bigint unsigned default 0,
   state smallint default 0,
   state_type smallint default 0,
-  start_time datetime  default '0000-00-00 00:00:00',
+  start_time timestamp  default '0000-00-00 00:00:00',
   start_time_usec  int default 0,
-  end_time datetime  default '0000-00-00 00:00:00',
+  end_time timestamp  default '0000-00-00 00:00:00',
   end_time_usec  int default 0,
   command_object_id bigint unsigned default 0,
   command_args varchar(255) character set latin1  default '',
@@ -445,7 +446,7 @@ CREATE TABLE IF NOT EXISTS icinga_eventhandlers (
 CREATE TABLE IF NOT EXISTS icinga_externalcommands (
   externalcommand_id serial,
   instance_id bigint unsigned default 0,
-  entry_time datetime  default '0000-00-00 00:00:00',
+  entry_time timestamp  default '0000-00-00 00:00:00',
   command_type smallint default 0,
   command_name varchar(128) character set latin1  default '',
   command_args varchar(255) character set latin1  default '',
@@ -461,7 +462,7 @@ CREATE TABLE IF NOT EXISTS icinga_externalcommands (
 CREATE TABLE IF NOT EXISTS icinga_flappinghistory (
   flappinghistory_id serial,
   instance_id bigint unsigned default 0,
-  event_time datetime  default '0000-00-00 00:00:00',
+  event_time timestamp  default '0000-00-00 00:00:00',
   event_time_usec  int default 0,
   event_type smallint default 0,
   reason_type smallint default 0,
@@ -470,7 +471,7 @@ CREATE TABLE IF NOT EXISTS icinga_flappinghistory (
   percent_state_change double  default '0',
   low_threshold double  default '0',
   high_threshold double  default '0',
-  comment_time datetime  default '0000-00-00 00:00:00',
+  comment_time timestamp  default '0000-00-00 00:00:00',
   internal_comment_id bigint unsigned default 0,
   PRIMARY KEY  (flappinghistory_id)
 ) ENGINE=InnoDB  COMMENT='Current and historical record of host and service flapping';
@@ -491,9 +492,9 @@ CREATE TABLE IF NOT EXISTS icinga_hostchecks (
   max_check_attempts smallint default 0,
   state smallint default 0,
   state_type smallint default 0,
-  start_time datetime  default '0000-00-00 00:00:00',
+  start_time timestamp  default '0000-00-00 00:00:00',
   start_time_usec  int default 0,
-  end_time datetime  default '0000-00-00 00:00:00',
+  end_time timestamp  default '0000-00-00 00:00:00',
   end_time_usec  int default 0,
   command_object_id bigint unsigned default 0,
   command_args varchar(255) character set latin1  default '',
@@ -694,7 +695,7 @@ CREATE TABLE IF NOT EXISTS icinga_hoststatus (
   hoststatus_id serial,
   instance_id bigint unsigned default 0,
   host_object_id bigint unsigned default 0,
-  status_update_time datetime  default '0000-00-00 00:00:00',
+  status_update_time timestamp  default '0000-00-00 00:00:00',
   output varchar(255) character set latin1  default '',
   long_output TEXT  default '',
   perfdata TEXT character set latin1  default '',
@@ -703,18 +704,18 @@ CREATE TABLE IF NOT EXISTS icinga_hoststatus (
   should_be_scheduled smallint default 0,
   current_check_attempt smallint default 0,
   max_check_attempts smallint default 0,
-  last_check datetime  default '0000-00-00 00:00:00',
-  next_check datetime  default '0000-00-00 00:00:00',
+  last_check timestamp  default '0000-00-00 00:00:00',
+  next_check timestamp  default '0000-00-00 00:00:00',
   check_type smallint default 0,
-  last_state_change datetime  default '0000-00-00 00:00:00',
-  last_hard_state_change datetime  default '0000-00-00 00:00:00',
+  last_state_change timestamp  default '0000-00-00 00:00:00',
+  last_hard_state_change timestamp  default '0000-00-00 00:00:00',
   last_hard_state smallint default 0,
-  last_time_up datetime  default '0000-00-00 00:00:00',
-  last_time_down datetime  default '0000-00-00 00:00:00',
-  last_time_unreachable datetime  default '0000-00-00 00:00:00',
+  last_time_up timestamp  default '0000-00-00 00:00:00',
+  last_time_down timestamp  default '0000-00-00 00:00:00',
+  last_time_unreachable timestamp  default '0000-00-00 00:00:00',
   state_type smallint default 0,
-  last_notification datetime  default '0000-00-00 00:00:00',
-  next_notification datetime  default '0000-00-00 00:00:00',
+  last_notification timestamp  default '0000-00-00 00:00:00',
+  next_notification timestamp  default '0000-00-00 00:00:00',
   no_more_notifications smallint default 0,
   notifications_enabled smallint default 0,
   problem_has_been_acknowledged smallint default 0,
@@ -806,8 +807,8 @@ CREATE TABLE IF NOT EXISTS icinga_instances (
 CREATE TABLE IF NOT EXISTS icinga_logentries (
   logentry_id serial,
   instance_id bigint unsigned default 0,
-  logentry_time datetime  default '0000-00-00 00:00:00',
-  entry_time datetime  default '0000-00-00 00:00:00',
+  logentry_time timestamp  default '0000-00-00 00:00:00',
+  entry_time timestamp  default '0000-00-00 00:00:00',
   entry_time_usec  int default 0,
   logentry_type  int default 0,
   logentry_data varchar(255) character set latin1  default '',
@@ -828,9 +829,9 @@ CREATE TABLE IF NOT EXISTS icinga_notifications (
   notification_type smallint default 0,
   notification_reason smallint default 0,
   object_id bigint unsigned default 0,
-  start_time datetime  default '0000-00-00 00:00:00',
+  start_time timestamp  default '0000-00-00 00:00:00',
   start_time_usec  int default 0,
-  end_time datetime  default '0000-00-00 00:00:00',
+  end_time timestamp  default '0000-00-00 00:00:00',
   end_time_usec  int default 0,
   state smallint default 0,
   output varchar(255) character set latin1  default '',
@@ -868,7 +869,7 @@ CREATE TABLE IF NOT EXISTS icinga_processevents (
   processevent_id serial,
   instance_id bigint unsigned default 0,
   event_type smallint default 0,
-  event_time datetime  default '0000-00-00 00:00:00',
+  event_time timestamp  default '0000-00-00 00:00:00',
   event_time_usec  int default 0,
   process_id bigint unsigned default 0,
   program_name varchar(16) character set latin1  default '',
@@ -886,14 +887,14 @@ CREATE TABLE IF NOT EXISTS icinga_processevents (
 CREATE TABLE IF NOT EXISTS icinga_programstatus (
   programstatus_id serial,
   instance_id bigint unsigned default 0,
-  status_update_time datetime  default '0000-00-00 00:00:00',
-  program_start_time datetime  default '0000-00-00 00:00:00',
-  program_end_time datetime  default '0000-00-00 00:00:00',
+  status_update_time timestamp  default '0000-00-00 00:00:00',
+  program_start_time timestamp  default '0000-00-00 00:00:00',
+  program_end_time timestamp  default '0000-00-00 00:00:00',
   is_currently_running smallint default 0,
   process_id bigint unsigned default 0,
   daemon_mode smallint default 0,
-  last_command_check datetime  default '0000-00-00 00:00:00',
-  last_log_rotation datetime  default '0000-00-00 00:00:00',
+  last_command_check timestamp  default '0000-00-00 00:00:00',
+  last_log_rotation timestamp  default '0000-00-00 00:00:00',
   notifications_enabled smallint default 0,
   active_service_checks_enabled smallint default 0,
   passive_service_checks_enabled smallint default 0,
@@ -938,17 +939,17 @@ CREATE TABLE IF NOT EXISTS icinga_scheduleddowntime (
   instance_id bigint unsigned default 0,
   downtime_type smallint default 0,
   object_id bigint unsigned default 0,
-  entry_time datetime  default '0000-00-00 00:00:00',
+  entry_time timestamp  default '0000-00-00 00:00:00',
   author_name varchar(64) character set latin1  default '',
   comment_data varchar(255) character set latin1  default '',
   internal_downtime_id bigint unsigned default 0,
   triggered_by_id bigint unsigned default 0,
   is_fixed smallint default 0,
   duration smallint default 0,
-  scheduled_start_time datetime  default '0000-00-00 00:00:00',
-  scheduled_end_time datetime  default '0000-00-00 00:00:00',
+  scheduled_start_time timestamp  default '0000-00-00 00:00:00',
+  scheduled_end_time timestamp  default '0000-00-00 00:00:00',
   was_started smallint default 0,
-  actual_start_time datetime  default '0000-00-00 00:00:00',
+  actual_start_time timestamp  default '0000-00-00 00:00:00',
   actual_start_time_usec  int default 0,
   PRIMARY KEY  (scheduleddowntime_id),
   UNIQUE KEY instance_id (instance_id,object_id,entry_time,internal_downtime_id)
@@ -969,9 +970,9 @@ CREATE TABLE IF NOT EXISTS icinga_servicechecks (
   max_check_attempts smallint default 0,
   state smallint default 0,
   state_type smallint default 0,
-  start_time datetime  default '0000-00-00 00:00:00',
+  start_time timestamp  default '0000-00-00 00:00:00',
   start_time_usec  int default 0,
-  end_time datetime  default '0000-00-00 00:00:00',
+  end_time timestamp  default '0000-00-00 00:00:00',
   end_time_usec  int default 0,
   command_object_id bigint unsigned default 0,
   command_args varchar(255) character set latin1  default '',
@@ -1167,7 +1168,7 @@ CREATE TABLE IF NOT EXISTS icinga_servicestatus (
   servicestatus_id serial,
   instance_id bigint unsigned default 0,
   service_object_id bigint unsigned default 0,
-  status_update_time datetime  default '0000-00-00 00:00:00',
+  status_update_time timestamp  default '0000-00-00 00:00:00',
   output varchar(255) character set latin1  default '',
   long_output TEXT  default '',
   perfdata TEXT character set latin1  default '',
@@ -1176,19 +1177,19 @@ CREATE TABLE IF NOT EXISTS icinga_servicestatus (
   should_be_scheduled smallint default 0,
   current_check_attempt smallint default 0,
   max_check_attempts smallint default 0,
-  last_check datetime  default '0000-00-00 00:00:00',
-  next_check datetime  default '0000-00-00 00:00:00',
+  last_check timestamp  default '0000-00-00 00:00:00',
+  next_check timestamp  default '0000-00-00 00:00:00',
   check_type smallint default 0,
-  last_state_change datetime  default '0000-00-00 00:00:00',
-  last_hard_state_change datetime  default '0000-00-00 00:00:00',
+  last_state_change timestamp  default '0000-00-00 00:00:00',
+  last_hard_state_change timestamp  default '0000-00-00 00:00:00',
   last_hard_state smallint default 0,
-  last_time_ok datetime  default '0000-00-00 00:00:00',
-  last_time_warning datetime  default '0000-00-00 00:00:00',
-  last_time_unknown datetime  default '0000-00-00 00:00:00',
-  last_time_critical datetime  default '0000-00-00 00:00:00',
+  last_time_ok timestamp  default '0000-00-00 00:00:00',
+  last_time_warning timestamp  default '0000-00-00 00:00:00',
+  last_time_unknown timestamp  default '0000-00-00 00:00:00',
+  last_time_critical timestamp  default '0000-00-00 00:00:00',
   state_type smallint default 0,
-  last_notification datetime  default '0000-00-00 00:00:00',
-  next_notification datetime  default '0000-00-00 00:00:00',
+  last_notification timestamp  default '0000-00-00 00:00:00',
+  next_notification timestamp  default '0000-00-00 00:00:00',
   no_more_notifications smallint default 0,
   notifications_enabled smallint default 0,
   problem_has_been_acknowledged smallint default 0,
@@ -1253,7 +1254,7 @@ CREATE TABLE IF NOT EXISTS icinga_service_contacts (
 CREATE TABLE IF NOT EXISTS icinga_statehistory (
   statehistory_id serial,
   instance_id bigint unsigned default 0,
-  state_time datetime  default '0000-00-00 00:00:00',
+  state_time timestamp  default '0000-00-00 00:00:00',
   state_time_usec  int default 0,
   object_id bigint unsigned default 0,
   state_change smallint default 0,
@@ -1277,9 +1278,9 @@ CREATE TABLE IF NOT EXISTS icinga_statehistory (
 CREATE TABLE IF NOT EXISTS icinga_systemcommands (
   systemcommand_id serial,
   instance_id bigint unsigned default 0,
-  start_time datetime  default '0000-00-00 00:00:00',
+  start_time timestamp  default '0000-00-00 00:00:00',
   start_time_usec  int default 0,
-  end_time datetime  default '0000-00-00 00:00:00',
+  end_time timestamp  default '0000-00-00 00:00:00',
   end_time_usec  int default 0,
   command_line varchar(1024) character set latin1  default '',
   timeout smallint default 0,
@@ -1302,9 +1303,9 @@ CREATE TABLE IF NOT EXISTS icinga_timedeventqueue (
   timedeventqueue_id serial,
   instance_id bigint unsigned default 0,
   event_type smallint default 0,
-  queued_time datetime  default '0000-00-00 00:00:00',
+  queued_time timestamp  default '0000-00-00 00:00:00',
   queued_time_usec  int default 0,
-  scheduled_time datetime  default '0000-00-00 00:00:00',
+  scheduled_time timestamp  default '0000-00-00 00:00:00',
   recurring_event smallint default 0,
   object_id bigint unsigned default 0,
   PRIMARY KEY  (timedeventqueue_id),
@@ -1321,14 +1322,14 @@ CREATE TABLE IF NOT EXISTS icinga_timedevents (
   timedevent_id serial,
   instance_id bigint unsigned default 0,
   event_type smallint default 0,
-  queued_time datetime  default '0000-00-00 00:00:00',
+  queued_time timestamp  default '0000-00-00 00:00:00',
   queued_time_usec  int default 0,
-  event_time datetime  default '0000-00-00 00:00:00',
+  event_time timestamp  default '0000-00-00 00:00:00',
   event_time_usec  int default 0,
-  scheduled_time datetime  default '0000-00-00 00:00:00',
+  scheduled_time timestamp  default '0000-00-00 00:00:00',
   recurring_event smallint default 0,
   object_id bigint unsigned default 0,
-  deletion_time datetime  default '0000-00-00 00:00:00',
+  deletion_time timestamp  default '0000-00-00 00:00:00',
   deletion_time_usec  int default 0,
   PRIMARY KEY  (timedevent_id),
   UNIQUE KEY instance_id (instance_id,event_type,scheduled_time,object_id)
@@ -1366,6 +1367,25 @@ CREATE TABLE IF NOT EXISTS icinga_timeperiod_timeranges (
   PRIMARY KEY  (timeperiod_timerange_id)
 ) ENGINE=InnoDB  COMMENT='Timeperiod definitions';
 
+-- --------------------------------------------------------
+
+--
+-- Table structure for table icinga_slahistory
+--
+
+CREATE TABLE IF NOT EXISTS icinga_slahistory (
+  slahistory_id serial,
+  instance_id bigint unsigned default 0,
+  start_time timestamp null default NULL,
+  end_time timestamp null default NULL,
+  acknowledgement_time timestamp null default NULL,
+  object_id bigint unsigned default 0,
+  state smallint default 0,
+  state_type smallint default '0',
+  scheduled_downtime tinyint(1) default 0,
+  PRIMARY KEY (slahistory_id)
+) ENGINE=InnoDB COMMENT='SLA statehistory';
+
 
 -- -----------------------------------------
 -- add index (delete)
@@ -1544,9 +1564,21 @@ CREATE INDEX loge_inst_id_time_idx on icinga_logentries (instance_id ASC, logent
 -- statehistory
 CREATE INDEX statehist_i_id_o_id_s_ty_s_ti on icinga_statehistory(instance_id, object_id, state_type, state_time);
 
+-- SLA statehistory
+CREATE INDEX slahist_i_id_o_id_s_ti_s_s_ti_e on icinga_slahistory(instance_id,object_id,start_time,end_time);
+
+-- Icinga Web Notifications
+CREATE INDEX notification_idx ON icinga_notifications(notification_type, object_id, start_time);
+CREATE INDEX notification_object_id_idx ON icinga_notifications(object_id);
+CREATE INDEX contact_notification_idx ON icinga_contactnotifications(notification_id, contact_object_id);
+CREATE INDEX contacts_object_id_idx ON icinga_contacts(contact_object_id);
+CREATE INDEX contact_notif_meth_notif_idx ON icinga_contactnotificationmethods(contactnotification_id, command_object_id);
+CREATE INDEX command_object_idx ON icinga_commands(object_id); 
+CREATE INDEX services_combined_object_idx ON icinga_services(service_object_id, host_object_id);
+
 -- -----------------------------------------
 -- set dbversion
 -- -----------------------------------------
-INSERT INTO icinga_dbversion (name, version) VALUES ('idoutils', '1.5.0') ON DUPLICATE KEY UPDATE version='1.5.0';
+INSERT INTO icinga_dbversion (name, version) VALUES ('idoutils', '1.6.0') ON DUPLICATE KEY UPDATE version='1.6.0';
 
 
