@@ -57,7 +57,7 @@ $$ LANGUAGE plpgsql;
 CREATE TABLE  icinga_acknowledgements (
   acknowledgement_id bigserial,
   instance_id bigint default 0,
-  entry_time timestamp  default '1970-01-01 00:00:00',
+  entry_time timestamp with time zone default '1970-01-01 00:00:00',
   entry_time_usec INTEGER  default 0,
   acknowledgement_type INTEGER  default 0,
   object_id bigint default 0,
@@ -67,6 +67,7 @@ CREATE TABLE  icinga_acknowledgements (
   is_sticky INTEGER  default 0,
   persistent_comment INTEGER  default 0,
   notify_contacts INTEGER  default 0,
+  end_time timestamp with time zone default '1970-01-01 00:00:00',
   CONSTRAINT PK_acknowledgement_id PRIMARY KEY (acknowledgement_id) 
 ) ;
 
@@ -95,20 +96,20 @@ CREATE TABLE  icinga_commands (
 CREATE TABLE  icinga_commenthistory (
   commenthistory_id bigserial,
   instance_id bigint default 0,
-  entry_time timestamp  default '1970-01-01 00:00:00',
+  entry_time timestamp with time zone default '1970-01-01 00:00:00',
   entry_time_usec INTEGER  default 0,
   comment_type INTEGER  default 0,
   entry_type INTEGER  default 0,
   object_id bigint default 0,
-  comment_time timestamp  default '1970-01-01 00:00:00',
+  comment_time timestamp with time zone default '1970-01-01 00:00:00',
   internal_comment_id bigint default 0,
   author_name TEXT  default '',
   comment_data TEXT  default '',
   is_persistent INTEGER  default 0,
   comment_source INTEGER  default 0,
   expires INTEGER  default 0,
-  expiration_time timestamp  default '1970-01-01 00:00:00',
-  deletion_time timestamp  default '1970-01-01 00:00:00',
+  expiration_time timestamp with time zone default '1970-01-01 00:00:00',
+  deletion_time timestamp with time zone default '1970-01-01 00:00:00',
   deletion_time_usec INTEGER  default 0,
   CONSTRAINT PK_commenthistory_id PRIMARY KEY (commenthistory_id) ,
   CONSTRAINT UQ_commenthistory UNIQUE (instance_id,comment_time,internal_comment_id)
@@ -123,19 +124,19 @@ CREATE TABLE  icinga_commenthistory (
 CREATE TABLE  icinga_comments (
   comment_id bigserial,
   instance_id bigint default 0,
-  entry_time timestamp  default '1970-01-01 00:00:00',
+  entry_time timestamp with time zone default '1970-01-01 00:00:00',
   entry_time_usec INTEGER  default 0,
   comment_type INTEGER  default 0,
   entry_type INTEGER  default 0,
   object_id bigint default 0,
-  comment_time timestamp  default '1970-01-01 00:00:00',
+  comment_time timestamp with time zone default '1970-01-01 00:00:00',
   internal_comment_id bigint default 0,
   author_name TEXT  default '',
   comment_data TEXT  default '',
   is_persistent INTEGER  default 0,
   comment_source INTEGER  default 0,
   expires INTEGER  default 0,
-  expiration_time timestamp  default '1970-01-01 00:00:00',
+  expiration_time timestamp with time zone default '1970-01-01 00:00:00',
   CONSTRAINT PK_comment_id PRIMARY KEY (comment_id) ,
   CONSTRAINT UQ_comments UNIQUE (instance_id,comment_time,internal_comment_id)
 )  ;
@@ -184,11 +185,11 @@ CREATE TABLE  icinga_conninfo (
   disposition TEXT  default '',
   connect_source TEXT  default '',
   connect_type TEXT  default '',
-  connect_time timestamp  default '1970-01-01 00:00:00',
-  disconnect_time timestamp  default '1970-01-01 00:00:00',
-  last_checkin_time timestamp  default '1970-01-01 00:00:00',
-  data_start_time timestamp  default '1970-01-01 00:00:00',
-  data_end_time timestamp  default '1970-01-01 00:00:00',
+  connect_time timestamp with time zone default '1970-01-01 00:00:00',
+  disconnect_time timestamp with time zone default '1970-01-01 00:00:00',
+  last_checkin_time timestamp with time zone default '1970-01-01 00:00:00',
+  data_start_time timestamp with time zone default '1970-01-01 00:00:00',
+  data_end_time timestamp with time zone default '1970-01-01 00:00:00',
   bytes_processed bigint  default 0,
   lines_processed bigint  default 0,
   entries_processed bigint  default 0,
@@ -235,9 +236,9 @@ CREATE TABLE  icinga_contactnotificationmethods (
   contactnotificationmethod_id bigserial,
   instance_id bigint default 0,
   contactnotification_id bigint default 0,
-  start_time timestamp  default '1970-01-01 00:00:00',
+  start_time timestamp with time zone default '1970-01-01 00:00:00',
   start_time_usec INTEGER  default 0,
-  end_time timestamp  default '1970-01-01 00:00:00',
+  end_time timestamp with time zone default '1970-01-01 00:00:00',
   end_time_usec INTEGER  default 0,
   command_object_id bigint default 0,
   command_args TEXT  default '',
@@ -256,9 +257,9 @@ CREATE TABLE  icinga_contactnotifications (
   instance_id bigint default 0,
   notification_id bigint default 0,
   contact_object_id bigint default 0,
-  start_time timestamp  default '1970-01-01 00:00:00',
+  start_time timestamp with time zone default '1970-01-01 00:00:00',
   start_time_usec INTEGER  default 0,
-  end_time timestamp  default '1970-01-01 00:00:00',
+  end_time timestamp with time zone default '1970-01-01 00:00:00',
   end_time_usec INTEGER  default 0,
   CONSTRAINT PK_contactnotification_id PRIMARY KEY (contactnotification_id) ,
   CONSTRAINT UQ_contactnotifications UNIQUE (instance_id,contact_object_id,start_time,start_time_usec)
@@ -308,11 +309,11 @@ CREATE TABLE  icinga_contactstatus (
   contactstatus_id bigserial,
   instance_id bigint default 0,
   contact_object_id bigint default 0,
-  status_update_time timestamp  default '1970-01-01 00:00:00',
+  status_update_time timestamp with time zone default '1970-01-01 00:00:00',
   host_notifications_enabled INTEGER  default 0,
   service_notifications_enabled INTEGER  default 0,
-  last_host_notification timestamp  default '1970-01-01 00:00:00',
-  last_service_notification timestamp  default '1970-01-01 00:00:00',
+  last_host_notification timestamp with time zone default '1970-01-01 00:00:00',
+  last_service_notification timestamp with time zone default '1970-01-01 00:00:00',
   modified_attributes INTEGER  default 0,
   modified_host_attributes INTEGER  default 0,
   modified_service_attributes INTEGER  default 0,
@@ -382,7 +383,7 @@ CREATE TABLE  icinga_customvariablestatus (
   customvariablestatus_id bigserial,
   instance_id bigint default 0,
   object_id bigint default 0,
-  status_update_time timestamp  default '1970-01-01 00:00:00',
+  status_update_time timestamp with time zone default '1970-01-01 00:00:00',
   has_been_modified INTEGER  default 0,
   varname TEXT  default '',
   varvalue TEXT  default '',
@@ -417,19 +418,19 @@ CREATE TABLE  icinga_downtimehistory (
   instance_id bigint default 0,
   downtime_type INTEGER  default 0,
   object_id bigint default 0,
-  entry_time timestamp  default '1970-01-01 00:00:00',
+  entry_time timestamp with time zone default '1970-01-01 00:00:00',
   author_name TEXT  default '',
   comment_data TEXT  default '',
   internal_downtime_id bigint default 0,
   triggered_by_id bigint default 0,
   is_fixed INTEGER  default 0,
   duration INTEGER  default 0,
-  scheduled_start_time timestamp  default '1970-01-01 00:00:00',
-  scheduled_end_time timestamp  default '1970-01-01 00:00:00',
+  scheduled_start_time timestamp with time zone default '1970-01-01 00:00:00',
+  scheduled_end_time timestamp with time zone default '1970-01-01 00:00:00',
   was_started INTEGER  default 0,
-  actual_start_time timestamp  default '1970-01-01 00:00:00',
+  actual_start_time timestamp with time zone default '1970-01-01 00:00:00',
   actual_start_time_usec INTEGER  default 0,
-  actual_end_time timestamp  default '1970-01-01 00:00:00',
+  actual_end_time timestamp with time zone default '1970-01-01 00:00:00',
   actual_end_time_usec INTEGER  default 0,
   was_cancelled INTEGER  default 0,
   CONSTRAINT PK_downtimehistory_id PRIMARY KEY (downtimehistory_id) ,
@@ -449,9 +450,9 @@ CREATE TABLE  icinga_eventhandlers (
   object_id bigint default 0,
   state INTEGER  default 0,
   state_type INTEGER  default 0,
-  start_time timestamp  default '1970-01-01 00:00:00',
+  start_time timestamp with time zone default '1970-01-01 00:00:00',
   start_time_usec INTEGER  default 0,
-  end_time timestamp  default '1970-01-01 00:00:00',
+  end_time timestamp with time zone default '1970-01-01 00:00:00',
   end_time_usec INTEGER  default 0,
   command_object_id bigint default 0,
   command_args TEXT  default '',
@@ -475,7 +476,7 @@ CREATE TABLE  icinga_eventhandlers (
 CREATE TABLE  icinga_externalcommands (
   externalcommand_id bigserial,
   instance_id bigint default 0,
-  entry_time timestamp  default '1970-01-01 00:00:00',
+  entry_time timestamp with time zone default '1970-01-01 00:00:00',
   command_type INTEGER  default 0,
   command_name TEXT  default '',
   command_args TEXT  default '',
@@ -491,7 +492,7 @@ CREATE TABLE  icinga_externalcommands (
 CREATE TABLE  icinga_flappinghistory (
   flappinghistory_id bigserial,
   instance_id bigint default 0,
-  event_time timestamp  default '1970-01-01 00:00:00',
+  event_time timestamp with time zone default '1970-01-01 00:00:00',
   event_time_usec INTEGER  default 0,
   event_type INTEGER  default 0,
   reason_type INTEGER  default 0,
@@ -500,7 +501,7 @@ CREATE TABLE  icinga_flappinghistory (
   percent_state_change double precision  default 0,
   low_threshold double precision  default 0,
   high_threshold double precision  default 0,
-  comment_time timestamp  default '1970-01-01 00:00:00',
+  comment_time timestamp with time zone default '1970-01-01 00:00:00',
   internal_comment_id bigint default 0,
   CONSTRAINT PK_flappinghistory_id PRIMARY KEY (flappinghistory_id) 
 ) ;
@@ -521,9 +522,9 @@ CREATE TABLE  icinga_hostchecks (
   max_check_attempts INTEGER  default 0,
   state INTEGER  default 0,
   state_type INTEGER  default 0,
-  start_time timestamp  default '1970-01-01 00:00:00',
+  start_time timestamp with time zone default '1970-01-01 00:00:00',
   start_time_usec INTEGER  default 0,
-  end_time timestamp  default '1970-01-01 00:00:00',
+  end_time timestamp with time zone default '1970-01-01 00:00:00',
   end_time_usec INTEGER  default 0,
   command_object_id bigint default 0,
   command_args TEXT  default '',
@@ -723,7 +724,7 @@ CREATE TABLE  icinga_hoststatus (
   hoststatus_id bigserial,
   instance_id bigint default 0,
   host_object_id bigint default 0,
-  status_update_time timestamp  default '1970-01-01 00:00:00',
+  status_update_time timestamp with time zone default '1970-01-01 00:00:00',
   output TEXT  default '',
   long_output TEXT  default '',
   perfdata TEXT  default '',
@@ -732,18 +733,18 @@ CREATE TABLE  icinga_hoststatus (
   should_be_scheduled INTEGER  default 0,
   current_check_attempt INTEGER  default 0,
   max_check_attempts INTEGER  default 0,
-  last_check timestamp  default '1970-01-01 00:00:00',
-  next_check timestamp  default '1970-01-01 00:00:00',
+  last_check timestamp with time zone default '1970-01-01 00:00:00',
+  next_check timestamp with time zone default '1970-01-01 00:00:00',
   check_type INTEGER  default 0,
-  last_state_change timestamp  default '1970-01-01 00:00:00',
-  last_hard_state_change timestamp  default '1970-01-01 00:00:00',
+  last_state_change timestamp with time zone default '1970-01-01 00:00:00',
+  last_hard_state_change timestamp with time zone default '1970-01-01 00:00:00',
   last_hard_state INTEGER  default 0,
-  last_time_up timestamp  default '1970-01-01 00:00:00',
-  last_time_down timestamp  default '1970-01-01 00:00:00',
-  last_time_unreachable timestamp  default '1970-01-01 00:00:00',
+  last_time_up timestamp with time zone default '1970-01-01 00:00:00',
+  last_time_down timestamp with time zone default '1970-01-01 00:00:00',
+  last_time_unreachable timestamp with time zone default '1970-01-01 00:00:00',
   state_type INTEGER  default 0,
-  last_notification timestamp  default '1970-01-01 00:00:00',
-  next_notification timestamp  default '1970-01-01 00:00:00',
+  last_notification timestamp with time zone default '1970-01-01 00:00:00',
+  next_notification timestamp with time zone default '1970-01-01 00:00:00',
   no_more_notifications INTEGER  default 0,
   notifications_enabled INTEGER  default 0,
   problem_has_been_acknowledged INTEGER  default 0,
@@ -835,8 +836,8 @@ CREATE TABLE  icinga_instances (
 CREATE TABLE  icinga_logentries (
   logentry_id bigserial,
   instance_id bigint default 0,
-  logentry_time timestamp  default '1970-01-01 00:00:00',
-  entry_time timestamp  default '1970-01-01 00:00:00',
+  logentry_time timestamp with time zone default '1970-01-01 00:00:00',
+  entry_time timestamp with time zone default '1970-01-01 00:00:00',
   entry_time_usec INTEGER  default 0,
   logentry_type INTEGER  default 0,
   logentry_data TEXT  default '',
@@ -857,9 +858,9 @@ CREATE TABLE  icinga_notifications (
   notification_type INTEGER  default 0,
   notification_reason INTEGER  default 0,
   object_id bigint default 0,
-  start_time timestamp  default '1970-01-01 00:00:00',
+  start_time timestamp with time zone default '1970-01-01 00:00:00',
   start_time_usec INTEGER  default 0,
-  end_time timestamp  default '1970-01-01 00:00:00',
+  end_time timestamp with time zone default '1970-01-01 00:00:00',
   end_time_usec INTEGER  default 0,
   state INTEGER  default 0,
   output TEXT  default '',
@@ -898,7 +899,7 @@ CREATE TABLE  icinga_processevents (
   processevent_id bigserial,
   instance_id bigint default 0,
   event_type INTEGER  default 0,
-  event_time timestamp  default '1970-01-01 00:00:00',
+  event_time timestamp with time zone default '1970-01-01 00:00:00',
   event_time_usec INTEGER  default 0,
   process_id bigint default 0,
   program_name TEXT  default '',
@@ -916,14 +917,14 @@ CREATE TABLE  icinga_processevents (
 CREATE TABLE  icinga_programstatus (
   programstatus_id bigserial,
   instance_id bigint default 0,
-  status_update_time timestamp  default '1970-01-01 00:00:00',
-  program_start_time timestamp  default '1970-01-01 00:00:00',
-  program_end_time timestamp  default '1970-01-01 00:00:00',
+  status_update_time timestamp with time zone default '1970-01-01 00:00:00',
+  program_start_time timestamp with time zone default '1970-01-01 00:00:00',
+  program_end_time timestamp with time zone default '1970-01-01 00:00:00',
   is_currently_running INTEGER  default 0,
   process_id bigint default 0,
   daemon_mode INTEGER  default 0,
-  last_command_check timestamp  default '1970-01-01 00:00:00',
-  last_log_rotation timestamp  default '1970-01-01 00:00:00',
+  last_command_check timestamp with time zone default '1970-01-01 00:00:00',
+  last_log_rotation timestamp with time zone default '1970-01-01 00:00:00',
   notifications_enabled INTEGER  default 0,
   active_service_checks_enabled INTEGER  default 0,
   passive_service_checks_enabled INTEGER  default 0,
@@ -968,17 +969,17 @@ CREATE TABLE  icinga_scheduleddowntime (
   instance_id bigint default 0,
   downtime_type INTEGER  default 0,
   object_id bigint default 0,
-  entry_time timestamp  default '1970-01-01 00:00:00',
+  entry_time timestamp with time zone default '1970-01-01 00:00:00',
   author_name TEXT  default '',
   comment_data TEXT  default '',
   internal_downtime_id bigint default 0,
   triggered_by_id bigint default 0,
   is_fixed INTEGER  default 0,
   duration INTEGER  default 0,
-  scheduled_start_time timestamp  default '1970-01-01 00:00:00',
-  scheduled_end_time timestamp  default '1970-01-01 00:00:00',
+  scheduled_start_time timestamp with time zone default '1970-01-01 00:00:00',
+  scheduled_end_time timestamp with time zone default '1970-01-01 00:00:00',
   was_started INTEGER  default 0,
-  actual_start_time timestamp  default '1970-01-01 00:00:00',
+  actual_start_time timestamp with time zone default '1970-01-01 00:00:00',
   actual_start_time_usec INTEGER  default 0,
   CONSTRAINT PK_scheduleddowntime_id PRIMARY KEY (scheduleddowntime_id) ,
   CONSTRAINT UQ_scheduleddowntime UNIQUE (instance_id,object_id,entry_time,internal_downtime_id)
@@ -999,9 +1000,9 @@ CREATE TABLE  icinga_servicechecks (
   max_check_attempts INTEGER  default 0,
   state INTEGER  default 0,
   state_type INTEGER  default 0,
-  start_time timestamp  default '1970-01-01 00:00:00',
+  start_time timestamp with time zone default '1970-01-01 00:00:00',
   start_time_usec INTEGER  default 0,
-  end_time timestamp  default '1970-01-01 00:00:00',
+  end_time timestamp with time zone default '1970-01-01 00:00:00',
   end_time_usec INTEGER  default 0,
   command_object_id bigint default 0,
   command_args TEXT  default '',
@@ -1196,7 +1197,7 @@ CREATE TABLE  icinga_servicestatus (
   servicestatus_id bigserial,
   instance_id bigint default 0,
   service_object_id bigint default 0,
-  status_update_time timestamp  default '1970-01-01 00:00:00',
+  status_update_time timestamp with time zone default '1970-01-01 00:00:00',
   output TEXT  default '',
   long_output TEXT  default '',
   perfdata TEXT  default '',
@@ -1205,19 +1206,19 @@ CREATE TABLE  icinga_servicestatus (
   should_be_scheduled INTEGER  default 0,
   current_check_attempt INTEGER  default 0,
   max_check_attempts INTEGER  default 0,
-  last_check timestamp  default '1970-01-01 00:00:00',
-  next_check timestamp  default '1970-01-01 00:00:00',
+  last_check timestamp with time zone default '1970-01-01 00:00:00',
+  next_check timestamp with time zone default '1970-01-01 00:00:00',
   check_type INTEGER  default 0,
-  last_state_change timestamp  default '1970-01-01 00:00:00',
-  last_hard_state_change timestamp  default '1970-01-01 00:00:00',
+  last_state_change timestamp with time zone default '1970-01-01 00:00:00',
+  last_hard_state_change timestamp with time zone default '1970-01-01 00:00:00',
   last_hard_state INTEGER  default 0,
-  last_time_ok timestamp  default '1970-01-01 00:00:00',
-  last_time_warning timestamp  default '1970-01-01 00:00:00',
-  last_time_unknown timestamp  default '1970-01-01 00:00:00',
-  last_time_critical timestamp  default '1970-01-01 00:00:00',
+  last_time_ok timestamp with time zone default '1970-01-01 00:00:00',
+  last_time_warning timestamp with time zone default '1970-01-01 00:00:00',
+  last_time_unknown timestamp with time zone default '1970-01-01 00:00:00',
+  last_time_critical timestamp with time zone default '1970-01-01 00:00:00',
   state_type INTEGER  default 0,
-  last_notification timestamp  default '1970-01-01 00:00:00',
-  next_notification timestamp  default '1970-01-01 00:00:00',
+  last_notification timestamp with time zone default '1970-01-01 00:00:00',
+  next_notification timestamp with time zone default '1970-01-01 00:00:00',
   no_more_notifications INTEGER  default 0,
   notifications_enabled INTEGER  default 0,
   problem_has_been_acknowledged INTEGER  default 0,
@@ -1282,7 +1283,7 @@ CREATE TABLE  icinga_service_contacts (
 CREATE TABLE  icinga_statehistory (
   statehistory_id bigserial,
   instance_id bigint default 0,
-  state_time timestamp  default '1970-01-01 00:00:00',
+  state_time timestamp with time zone default '1970-01-01 00:00:00',
   state_time_usec INTEGER  default 0,
   object_id bigint default 0,
   state_change INTEGER  default 0,
@@ -1306,9 +1307,9 @@ CREATE TABLE  icinga_statehistory (
 CREATE TABLE  icinga_systemcommands (
   systemcommand_id bigserial,
   instance_id bigint default 0,
-  start_time timestamp  default '1970-01-01 00:00:00',
+  start_time timestamp with time zone default '1970-01-01 00:00:00',
   start_time_usec INTEGER  default 0,
-  end_time timestamp  default '1970-01-01 00:00:00',
+  end_time timestamp with time zone default '1970-01-01 00:00:00',
   end_time_usec INTEGER  default 0,
   command_line TEXT  default '',
   timeout INTEGER  default 0,
@@ -1331,9 +1332,9 @@ CREATE TABLE  icinga_timedeventqueue (
   timedeventqueue_id bigserial,
   instance_id bigint default 0,
   event_type INTEGER  default 0,
-  queued_time timestamp  default '1970-01-01 00:00:00',
+  queued_time timestamp with time zone default '1970-01-01 00:00:00',
   queued_time_usec INTEGER  default 0,
-  scheduled_time timestamp  default '1970-01-01 00:00:00',
+  scheduled_time timestamp with time zone default '1970-01-01 00:00:00',
   recurring_event INTEGER  default 0,
   object_id bigint default 0,
   CONSTRAINT PK_timedeventqueue_id PRIMARY KEY (timedeventqueue_id) 
@@ -1349,14 +1350,14 @@ CREATE TABLE  icinga_timedevents (
   timedevent_id bigserial,
   instance_id bigint default 0,
   event_type INTEGER  default 0,
-  queued_time timestamp  default '1970-01-01 00:00:00',
+  queued_time timestamp with time zone default '1970-01-01 00:00:00',
   queued_time_usec INTEGER  default 0,
-  event_time timestamp  default '1970-01-01 00:00:00',
+  event_time timestamp with time zone default '1970-01-01 00:00:00',
   event_time_usec INTEGER  default 0,
-  scheduled_time timestamp  default '1970-01-01 00:00:00',
+  scheduled_time timestamp with time zone default '1970-01-01 00:00:00',
   recurring_event INTEGER  default 0,
   object_id bigint default 0,
-  deletion_time timestamp  default '1970-01-01 00:00:00',
+  deletion_time timestamp with time zone default '1970-01-01 00:00:00',
   deletion_time_usec INTEGER  default 0,
   CONSTRAINT PK_timedevent_id PRIMARY KEY (timedevent_id) ,
   CONSTRAINT UQ_timedevents UNIQUE (instance_id,event_type,scheduled_time,object_id)
@@ -1394,6 +1395,26 @@ CREATE TABLE  icinga_timeperiod_timeranges (
   CONSTRAINT PK_timeperiod_timerange_id PRIMARY KEY (timeperiod_timerange_id)
 ) ;
 
+-- --------------------------------------------------------
+
+--
+-- Table structure for table icinga_slahistory
+--
+                                                                                
+CREATE TABLE icinga_slahistory (
+  slahistory_id serial,
+  instance_id bigint default 0,
+  start_time timestamp with time zone default '1970-01-01 00:00:00',
+  end_time timestamp with time zone default '1970-01-01 00:00:00',
+  acknowledgement_time timestamp with time zone default '1970-01-01 00:00:00',
+  object_id bigint default 0,
+  state INTEGER default 0,
+  state_type INTEGER default '0',
+  scheduled_downtime INTEGER default 0,
+  CONSTRAINT PK_slahistory_id PRIMARY KEY (slahistory_id)
+) ;
+
+
 
 -- -----------------------------------------
 -- add index (delete)
@@ -1570,13 +1591,24 @@ CREATE INDEX loge_inst_id_time_idx on icinga_logentries (instance_id, logentry_t
 -- CREATE INDEX sched_d_t_start_time_idx on icinga_scheduleddowntime(scheduled_start_time);
 -- CREATE INDEX sched_d_t_end_time_idx on icinga_scheduleddowntime(scheduled_end_time);
 
+-- Icinga Web Notifications
+CREATE INDEX notification_idx ON icinga_notifications(notification_type, object_id, start_time);
+CREATE INDEX notification_object_id_idx ON icinga_notifications(object_id);
+CREATE INDEX contact_notification_idx ON icinga_contactnotifications(notification_id, contact_object_id);
+CREATE INDEX contacts_object_id_idx ON icinga_contacts(contact_object_id);
+CREATE INDEX contact_notif_meth_notif_idx ON icinga_contactnotificationmethods(contactnotification_id, command_object_id);
+CREATE INDEX command_object_idx ON icinga_commands(object_id);                         
+CREATE INDEX services_combined_object_idx ON icinga_services(service_object_id, host_object_id);
+
 -- statehistory
 CREATE INDEX statehist_i_id_o_id_s_ty_s_ti on icinga_statehistory(instance_id, object_id, state_type, state_time);
 
+-- SLA statehistory
+CREATE INDEX slahist_i_id_o_id_s_ti_s_s_ti_e on icinga_slahistory(instance_id,object_id,start_time,end_time);
 
 -- -----------------------------------------
 -- set dbversion
 -- -----------------------------------------
 
-SELECT updatedbversion('1.5.0');
+SELECT updatedbversion('1.6.0');
 
