@@ -21,7 +21,8 @@
 #include "../include/ido2db.h"
 #include "../include/db.h"
 #include "../include/dbhandlers.h"
-
+#include "../include/sla.h"
+#include "../include/logging.h"
 
 #ifdef HAVE_SSL
 #include "../../../include/dh.h"
@@ -85,15 +86,14 @@ int ido2db_debug_verbosity = IDO2DB_DEBUGV_BASIC;
 FILE *ido2db_debug_file_fp = NULL;
 unsigned long ido2db_max_debug_file_size = 0L;
 
+int enable_sla = IDO_FALSE;
+int ido2db_debug_readable_timestamp = IDO_FALSE;
+
 int stop_signal_detected = IDO_FALSE;
 
 char *sigs[35] = {"EXIT", "HUP", "INT", "QUIT", "ILL", "TRAP", "ABRT", "BUS", "FPE", "KILL", "USR1", "SEGV", "USR2", "PIPE", "ALRM", "TERM", "STKFLT", "CHLD", "CONT", "STOP", "TSTP", "TTIN", "TTOU", "URG", "XCPU", "XFSZ", "VTALRM", "PROF", "WINCH", "IO", "PWR", "UNUSED", "ZERR", "DEBUG", (char *)NULL};
 
 
-int ido2db_open_debug_log(void);
-int ido2db_close_debug_log(void);
-
-
 int dummy;	/* reduce compiler warnings */
 
 
@@ -122,11 +122,10 @@ int main(int argc, char **argv) {
 			printf("Incorrect command line arguments supplied\n");
 
 		printf("\n");
-		printf("%s %s\n", IDO2DB_NAME, IDO2DB_VERSION);
-		printf("Copyright(c) 2005-2008 Ethan Galstad (nagios@nagios.org)\n");
-		printf("Copyright(c) 2009-2011 Icinga Development Team (http://www.icinga.org)\n");
-		printf("Last Modified: %s\n", IDO2DB_DATE);
-		printf("License: GPL v2\n");
+		printf("%s %s\n", IDO2DB_NAME, IDO_VERSION);
+		printf("%s\n", IDO_COPYRIGHT);
+		printf("Last Modified: %s\n", IDO_DATE);
+		printf("%s\n", IDO_LICENSE);
 #ifdef HAVE_SSL
 		printf("SSL/TLS Available: Anonymous DH Mode, OpenSSL 0.9.6 or higher required\n");
 #endif
@@ -153,8 +152,8 @@ int main(int argc, char **argv) {
 	}
 
 	/* print starting info to syslog */
-	syslog(LOG_USER | LOG_INFO, "%s %s (%s) Copyright (c) 2005-2008 Ethan Galstad (nagios@nagios.org), Copyright (c) 2009-2011 Icinga Development Team (http://www.icinga.org))", IDO2DB_NAME, IDO2DB_VERSION, IDO2DB_DATE);
-	syslog(LOG_USER | LOG_INFO, "%s %s starting... (PID=%d)\n", IDO2DB_NAME, IDO2DB_VERSION, (int)getpid());
+	syslog(LOG_USER | LOG_INFO, "%s %s (%s) %s", IDO2DB_NAME, IDO_VERSION, IDO_DATE, IDO_COPYRIGHT);
+	syslog(LOG_USER | LOG_INFO, "%s %s starting... (PID=%d)\n", IDO2DB_NAME, IDO_VERSION, (int)getpid());
 
 	if (ido2db_socket_type == IDO_SINK_UNIXSOCKET && use_ssl == IDO_TRUE) {
 		printf("SSL is not allowed on socket_type=unix\n");
@@ -222,6 +221,8 @@ int main(int argc, char **argv) {
 		printf("Support for the specified database server is either not yet supported, or was not found on your system.\n");
 
 		numdrivers = dbi_initialize(NULL);
+		if (numdrivers == -1)
+			numdrivers = 0;
 
 		fprintf(stderr, "%d drivers available: ", numdrivers);
 		while ((driver = dbi_driver_list(driver)) != NULL) {
@@ -539,6 +540,12 @@ int ido2db_process_config_var(char *arg) {
 		ido2db_db_settings.max_logentries_age = strtoul(val, NULL, 0) * 60;
 	else if (!strcmp(var, "max_acknowledgements_age"))
 		ido2db_db_settings.max_acknowledgements_age = strtoul(val, NULL, 0) * 60;
+	else if (!strcmp(var, "max_notifications_age"))
+		ido2db_db_settings.max_notifications_age = strtoul(val, NULL, 0) * 60;
+	else if (!strcmp(var, "max_contactnotifications_age"))
+		ido2db_db_settings.max_contactnotifications_age = strtoul(val, NULL, 0) * 60;
+	else if (!strcmp(var, "max_contactnotificationmethods_age"))
+		ido2db_db_settings.max_contactnotificationmethods_age = strtoul(val, NULL, 0) * 60;
 
 	else if (!strcmp(var, "trim_db_interval"))
 		ido2db_db_settings.trim_db_interval = strtoul(val, NULL, 0);
@@ -583,6 +590,10 @@ int ido2db_process_config_var(char *arg) {
 		ido2db_db_settings.oci_errors_to_syslog = (atoi(val) > 0) ? IDO_TRUE : IDO_FALSE;
 	} else if (!strcmp(var, "oracle_trace_level")) {
 		ido2db_db_settings.oracle_trace_level = atoi(val);
+	} else if (!strcmp(var, "enable_sla")) {
+		enable_sla = (atoi(val) > 0) ? IDO_TRUE : IDO_FALSE;
+	} else if (!strcmp(var, "debug_readable_timestamp")) {
+		ido2db_debug_readable_timestamp = (atoi(val) > 0) ? IDO_TRUE : IDO_FALSE;
 	}
 	//syslog(LOG_ERR,"ido2db_process_config_var(%s) end\n",var);
 
@@ -613,6 +624,9 @@ int ido2db_initialize_variables(void) {
 	ido2db_db_settings.max_externalcommands_age = 0L;
 	ido2db_db_settings.max_logentries_age = 0L;
 	ido2db_db_settings.max_acknowledgements_age = 0L;
+	ido2db_db_settings.max_notifications_age = 0L;
+	ido2db_db_settings.max_contactnotifications_age = 0L;
+	ido2db_db_settings.max_contactnotificationmethods_age = 0L;
 	ido2db_db_settings.trim_db_interval = (unsigned long)DEFAULT_TRIM_DB_INTERVAL; /* set the default if missing in ido2db.cfg */
 	ido2db_db_settings.housekeeping_thread_startup_delay = (unsigned long)DEFAULT_HOUSEKEEPING_THREAD_STARTUP_DELAY; /* set the default if missing in ido2db.cfg */
 	ido2db_db_settings.clean_realtime_tables_on_core_startup = IDO_TRUE; /* default is cleaning on startup */
@@ -1236,8 +1250,7 @@ int ido2db_handle_client_connection(int sd) {
 			ido2db_log_debug_info(IDO2DB_DEBUGL_PROCESSINFO, 2, "ido2db_handle_client_connection() idi.dbinfo.connected is '%d'\n", idi.dbinfo.connected);
 
 			/* terminate threads */
-			/*terminate_worker_thread();*/
-			terminate_cleanup_thread();
+			ido2db_terminate_threads();
 
 			/* free memory allocated to dynamic buffer */
 			ido_dbuf_free(&dbuf);
@@ -1355,8 +1368,7 @@ int ido2db_handle_client_connection(int sd) {
 #endif
 
 	/* terminate threads */
-	/*terminate_worker_thread();*/
-	terminate_cleanup_thread();
+	ido2db_terminate_threads();
 
 	/* free memory allocated to dynamic buffer */
 	ido_dbuf_free(&dbuf);
@@ -2503,94 +2515,9 @@ int ido2db_convert_string_to_timeval(char *buf, struct timeval *tv) {
 /* LOGGING ROUTINES                                                         */
 /****************************************************************************/
 
-/* opens the debug log for writing */
-int ido2db_open_debug_log(void) {
-
-	ido2db_log_debug_info(IDO2DB_DEBUGL_PROCESSINFO, 2, "ido2db_open_debug_log() start\n");
-
-	/* don't do anything if we're not debugging */
-	if (ido2db_debug_level == IDO2DB_DEBUGL_NONE)
-		return IDO_OK;
-
-	if ((ido2db_debug_file_fp = fopen(ido2db_debug_file, "a+")) == NULL) {
-		syslog(LOG_ERR, "Warning: Could not open debug file '%s' - '%s'", ido2db_debug_file, strerror(errno));
-		return IDO_ERROR;
-	}
-
-	ido2db_log_debug_info(IDO2DB_DEBUGL_PROCESSINFO, 2, "ido2db_open_debug_log() end\n");
-
-	return IDO_OK;
-}
-
-
-/* closes the debug log */
-int ido2db_close_debug_log(void) {
-
-	if (ido2db_debug_file_fp != NULL)
-		fclose(ido2db_debug_file_fp);
-
-	ido2db_debug_file_fp = NULL;
-
-	return IDO_OK;
-}
-
-
-/* write to the debug log */
-int ido2db_log_debug_info(int level, int verbosity, const char *fmt, ...) {
-	va_list ap;
-	char *temp_path = NULL;
-	struct timeval current_time;
-
-	if (!(ido2db_debug_level == IDO2DB_DEBUGL_ALL || (level & ido2db_debug_level)))
-		return IDO_OK;
-
-	if (verbosity > ido2db_debug_verbosity)
-		return IDO_OK;
-
-	if (ido2db_debug_file_fp == NULL)
-		return IDO_ERROR;
-
-	/* write the timestamp */
-	gettimeofday(&current_time, NULL);
-	fprintf(ido2db_debug_file_fp, "[%lu.%06lu] [%03d.%d] [pid=%lu] ", current_time.tv_sec, current_time.tv_usec, level, verbosity, (unsigned long)getpid());
-
-	/* write the data */
-	va_start(ap, fmt);
-	vfprintf(ido2db_debug_file_fp, fmt, ap);
-	va_end(ap);
-
-	/* flush, so we don't have problems tailing or when fork()ing */
-	fflush(ido2db_debug_file_fp);
-
-	/* if file has grown beyond max, rotate it */
-	if ((unsigned long)ftell(ido2db_debug_file_fp) > ido2db_max_debug_file_size && ido2db_max_debug_file_size > 0L) {
-
-		/* close the file */
-		ido2db_close_debug_log();
-
-		/* rotate the log file */
-		if (asprintf(&temp_path, "%s.old", ido2db_debug_file) == -1)
-			temp_path = NULL;
-
-		if (temp_path) {
-
-			/* unlink the old debug file */
-			unlink(temp_path);
-
-			/* rotate the debug file */
-			my_rename(ido2db_debug_file, temp_path);
-
-			/* free memory */
-			my_free(temp_path);
-		}
-
-		/* open a new file */
-		ido2db_open_debug_log();
-	}
-
-	return IDO_OK;
-}
-
+/*
+ * moved to logging.c/h
+ */
 
 /********************************************************************
  *
