@@ -73,6 +73,8 @@ extern int	      dump_retained_host_service_states_to_neb;
 extern int            use_retained_scheduling_info;
 extern int            retention_scheduling_horizon;
 
+extern time_t         last_program_stop;
+
 extern unsigned long  next_comment_id;
 extern unsigned long  next_downtime_id;
 extern unsigned long  next_event_id;
@@ -397,6 +399,7 @@ int xrddefault_save_state_information(void) {
 		fprintf(fp, "notifications_enabled=%d\n", temp_host->notifications_enabled);
 		fprintf(fp, "problem_has_been_acknowledged=%d\n", temp_host->problem_has_been_acknowledged);
 		fprintf(fp, "acknowledgement_type=%d\n", temp_host->acknowledgement_type);
+		fprintf(fp, "acknowledgement_end_time=%lu\n", temp_host->acknowledgement_end_time);
 		fprintf(fp, "active_checks_enabled=%d\n", temp_host->checks_enabled);
 		fprintf(fp, "passive_checks_enabled=%d\n", temp_host->accept_passive_host_checks);
 		fprintf(fp, "event_handler_enabled=%d\n", temp_host->event_handler_enabled);
@@ -478,6 +481,7 @@ int xrddefault_save_state_information(void) {
 		fprintf(fp, "event_handler_enabled=%d\n", temp_service->event_handler_enabled);
 		fprintf(fp, "problem_has_been_acknowledged=%d\n", temp_service->problem_has_been_acknowledged);
 		fprintf(fp, "acknowledgement_type=%d\n", temp_service->acknowledgement_type);
+		fprintf(fp, "acknowledgement_end_time=%lu\n", temp_service->acknowledgement_end_time);
 		fprintf(fp, "flap_detection_enabled=%d\n", temp_service->flap_detection_enabled);
 		fprintf(fp, "failure_prediction_enabled=%d\n", temp_service->failure_prediction_enabled);
 		fprintf(fp, "process_performance_data=%d\n", temp_service->process_performance_data);
@@ -815,6 +819,18 @@ int xrddefault_read_retention_file_information(char *retention_file, int overwri
 					if (temp_host->last_hard_state_change == (time_t)0)
 						temp_host->last_hard_state_change = temp_host->last_state_change;
 
+					/* handle expiring acknowledgements */
+					if (temp_host->problem_has_been_acknowledged == TRUE && temp_host->acknowledgement_end_time != (time_t)0) {
+						time(&current_time);
+						if (temp_host->acknowledgement_end_time > current_time) {
+							schedule_new_event(EVENT_EXPIRE_ACKNOWLEDGEMENT, TRUE, (temp_host->acknowledgement_end_time + 1), FALSE, 0, NULL, FALSE, temp_host, NULL, HOST_ACKNOWLEDGEMENT);
+						} else {
+							temp_host->problem_has_been_acknowledged = FALSE;
+							temp_host->acknowledgement_type = ACKNOWLEDGEMENT_NONE;
+							temp_host->acknowledgement_end_time = (time_t)0;
+						}
+					}
+
 					/* update host status */
 					/* MF 2011-07-22: see #1742 - do not dump retained host state into
 					   neb modules, setting aggregated dumps to true. made a config option. */
@@ -893,6 +909,18 @@ int xrddefault_read_retention_file_information(char *retention_file, int overwri
 					if (temp_service->last_hard_state_change == (time_t)0)
 						temp_service->last_hard_state_change = temp_service->last_state_change;
 
+					/* handle expiring acknowledgements */
+					if (temp_service->problem_has_been_acknowledged == TRUE && temp_service->acknowledgement_end_time != (time_t)0) {
+						time(&current_time);
+						if (temp_service->acknowledgement_end_time > current_time) {
+							schedule_new_event(EVENT_EXPIRE_ACKNOWLEDGEMENT, TRUE, (temp_service->acknowledgement_end_time + 1), FALSE, 0, NULL, FALSE, temp_service, NULL, SERVICE_ACKNOWLEDGEMENT);
+						} else {
+							temp_service->problem_has_been_acknowledged = FALSE;
+							temp_service->acknowledgement_type = ACKNOWLEDGEMENT_NONE;
+							temp_service->acknowledgement_end_time = (time_t)0;
+						}
+					}
+
 					/* update service status */
 					/* MF 2011-07-22: see #1742 - do not dump retained service state into
 					   neb modules, setting aggregated dumps to true. made a config option. */
@@ -1093,6 +1121,8 @@ int xrddefault_read_retention_file_information(char *retention_file, int overwri
 						scheduling_info_is_ok = TRUE;
 					else
 						scheduling_info_is_ok = FALSE;
+					/* save that for determining freshness of checkresults on startup */
+					last_program_stop = creation_time;
 				} else if (!strcmp(var, "version")) {
 				}
 				break;
@@ -1312,6 +1342,8 @@ int xrddefault_read_retention_file_information(char *retention_file, int overwri
 							temp_host->problem_has_been_acknowledged = (atoi(val) > 0) ? TRUE : FALSE;
 						else if (!strcmp(var, "acknowledgement_type"))
 							temp_host->acknowledgement_type = atoi(val);
+						else if (!strcmp(var, "acknowledgement_end_time"))
+							temp_host->acknowledgement_end_time = strtoul(val, NULL, 10);
 						else if (!strcmp(var, "notifications_enabled")) {
 							if (temp_host->modified_attributes & MODATTR_NOTIFICATIONS_ENABLED)
 								temp_host->notifications_enabled = (atoi(val) > 0) ? TRUE : FALSE;
@@ -1575,6 +1607,8 @@ int xrddefault_read_retention_file_information(char *retention_file, int overwri
 							temp_service->problem_has_been_acknowledged = (atoi(val) > 0) ? TRUE : FALSE;
 						else if (!strcmp(var, "acknowledgement_type"))
 							temp_service->acknowledgement_type = atoi(val);
+						else if (!strcmp(var, "acknowledgement_end_time"))
+							temp_service->acknowledgement_end_time = strtoul(val, NULL, 10);
 						else if (!strcmp(var, "notifications_enabled")) {
 							if (temp_service->modified_attributes & MODATTR_NOTIFICATIONS_ENABLED)
 								temp_service->notifications_enabled = (atoi(val) > 0) ? TRUE : FALSE;
